@@ -17,8 +17,13 @@ ${QMAKE} -o src/tools/Makefile  src/tools/tools.pro
 ${QMAKE} -o doc/Makefile        doc/doc.pro
 ${QMAKE} -o po/Makefile         po/po.pro
 
+test -d src/unit_tests && ${QMAKE} -o src/unit_tests/importer/Makefile \
+                                      src/unit_tests/importer/importer.pro
+
 if test -n "$CCACHE"; then
 
+${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/antlr/Makefile     src/antlr/antlr.pro
+
 ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/gui/Makefile       src/gui/gui.pro
 ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/fwblookup/Makefile src/fwblookup/fwblookup.pro
 ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/fwbedit/Makefile   src/fwbedit/fwbedit.pro
@@ -28,8 +33,12 @@ ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/pf/Makefile        src/pf/pf.pro
 ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/ipf/Makefile       src/ipf/ipf.pro
 ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/ipfw/Makefile      src/ipfw/ipfw.pro
 
+${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/parsers/Makefile   src/parsers/parsers.pro
+
 else
 
+${QMAKE}  -o src/antlr/Makefile     src/antlr/antlr.pro
+
 ${QMAKE}  -o src/gui/Makefile       src/gui/gui.pro
 ${QMAKE}  -o src/fwblookup/Makefile src/fwblookup/fwblookup.pro
 ${QMAKE}  -o src/fwbedit/Makefile   src/fwbedit/fwbedit.pro
@@ -39,5 +48,7 @@ ${QMAKE}  -o src/pf/Makefile        src/pf/pf.pro
 ${QMAKE}  -o src/ipf/Makefile       src/ipf/ipf.pro
 ${QMAKE}  -o src/ipfw/Makefile      src/ipfw/ipfw.pro
 
+${QMAKE}  -o src/parsers/Makefile   src/parsers/parsers.pro
+
 fi
 
