@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.cpp,v 1.28 2007/01/15 04:37:51 vkurland Exp $
+  $Id: ActionsDialog.cpp,v 1.29 2007/06/14 02:55:29 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -238,7 +238,7 @@ void ActionsDialog::setRule(PolicyRule *r )
     data.clear();
 
     data.registerOption ( ipt_mark_connections, ropt , "ipt_mark_connections");
-    data.registerOption ( ipt_mark_prerouting , ropt , "ipt_mark_prerouting");
+//    data.registerOption ( ipt_mark_prerouting , ropt , "ipt_mark_prerouting");
     data.registerOption ( accountingvalue_str , ropt , "rule_name_accounting");
     data.registerOption ( usePortNum          , ropt , "ipfw_pipe_queue_num");
     data.registerOption ( divertPortNum       , ropt , "ipfw_pipe_port_num");
