@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogData.cpp,v 1.7 2006/10/24 03:43:25 vkurland Exp $
+  $Id: DialogData.cpp,v 1.8 2007/05/22 22:59:31 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -124,7 +124,7 @@ void DialogData::loadToWidget( DialogOption &dopt , bool override)
  *  the array from 1).
  */
             cbx->clear();
-            int idx = 0;
+            unsigned idx = 0;
             QStringList::iterator i1 = dopt.mapping.begin();
             QStringList::iterator i2 = dopt.mapping.begin();
             ++i2;
