@@ -7,7 +7,7 @@
   Author:  Vadim Kurland     vadim@fwbuilder.org
            Illiya Yalovoy    <yalovoy@gmail.com>
 
-  $Id: DiscoveryDruid.cpp,v 1.37 2007/06/13 02:58:48 vkurland Exp $
+  $Id: DiscoveryDruid.cpp,v 1.38 2007/08/06 07:07:22 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1469,7 +1469,7 @@ void DiscoveryDruid::loadDataFromCrawler()
 
             buf = QString(od.addr.toString().c_str()) + " : " + od.sysname.c_str();
             discoverylog->append(buf);
-
+            if (fwbdebug)  qDebug(QString("LOG: ")+buf);
         }
 
         Objects[od.toString().c_str()]=od;
@@ -1647,6 +1647,7 @@ void DiscoveryDruid::updateLog()
             {
                 buf = thread->Log->getLine().c_str();
                 discoverylog->insert(buf);
+                if (fwbdebug)  qDebug(QString("LOG: ")+buf);
             }
         }
     }
@@ -1859,6 +1860,7 @@ int DiscoveryDruid::monitorOperation()
     {
         buf= logger->getLine().c_str();
         discoverylog->append(buf);
+        if (fwbdebug)  qDebug(QString("LOG: ")+buf);
         fl=true;
     }
     if (fl)
@@ -1883,6 +1885,7 @@ int DiscoveryDruid::monitorOperation()
     {
         buf= ex->toString().c_str();
         discoverylog->append(buf+"\n");
+        if (fwbdebug)  qDebug(QString("LOG: ")+buf+"\n");
       //  completed(-1);   // this sends signal to another widget
     } else
     {
@@ -2350,9 +2353,6 @@ void ConfigImport::run()
             *Log << e.toString() << "\n";
         }
 
-        if (fwbdebug)
-            qDebug(imp->getDebugOutput().c_str());
-
     } else
     {
         *Log << "Can not import configuration for choosen platform\n";
