@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.cpp,v 1.44 2005/01/30 07:41:15 vkurland Exp $
+  $Id: FWBSettings.cpp,v 1.47 2006/06/26 03:21:00 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -70,31 +70,30 @@ using namespace libfwbuilder;
  * reading key Install_Dir under HKLM Software\NetCitadel\FirewallBuilder
  */
 
-const char* DTDSetpath           = "/FirewallBuilder2/System/DTDPath";
-const char* ResSetpath           = "/FirewallBuilder2/System/ResPath";
-const char* wdirSetpath          = "/FirewallBuilder2/Environment/WDir";
-const char* ofdirSetpath         = "/FirewallBuilder2/Environment/OpenFileDir";
-const char* sfdirSetpath         = "/FirewallBuilder2/Environment/SaveFileDir";
-const char* startupActionSetpath = "/FirewallBuilder2/Environment/StartupAction";
-const char* labelColorPath       = "/FirewallBuilder2/ColorLabels/color_";
-const char* labelTextPath        = "/FirewallBuilder2/ColorLabels/text_";
-const char* lastEditedSetpath    = "/FirewallBuilder2/Environment/LastEdited";
-const char* autoSave             = "/FirewallBuilder2/Environment/autoSave";
-const char* expandTreeSetpath    = "/FirewallBuilder2/UI/ExpandTree";
-const char* MergeLibsSetpath     = "/FirewallBuilder2/UI/MergeLibraries";
-const char* infoStyleSetpath     = "/FirewallBuilder2/UI/InfoWindowStyle";
-const char* infoWindowHSetpath   = "/FirewallBuilder2/UI/InfoWindowHeight";
-const char* groupModeSetpath     = "/FirewallBuilder2/UI/GroupViewMode";
-const char* groupColsSetpath     = "/FirewallBuilder2/UI/GroupViewColumns";
-const char* objTooltips          = "/FirewallBuilder2/UI/objTooltips";
-const char* tooltipDelay         = "/FirewallBuilder2/UI/tooltipDelay";
-const char* emptyRCSLog          = "/FirewallBuilder2/RCS/emptyLog";
-const char* dontSaveStdLib       = "/FirewallBuilder2/DataFormat/dontSaveStdLib";
-const char* WindowGeometrySetpath= "/FirewallBuilder2/Layout/";
-const char* screenPositionSetpath= "/FirewallBuilder2/ScreenPos/";
+const char* DTDSetpath           = SETTINGS_PATH_PREFIX "/System/DTDPath";
+const char* ResSetpath           = SETTINGS_PATH_PREFIX "/System/ResPath";
+const char* wdirSetpath          = SETTINGS_PATH_PREFIX "/Environment/WDir";
+const char* ofdirSetpath         = SETTINGS_PATH_PREFIX "/Environment/OpenFileDir";
+const char* sfdirSetpath         = SETTINGS_PATH_PREFIX "/Environment/SaveFileDir";
+const char* startupActionSetpath = SETTINGS_PATH_PREFIX "/Environment/StartupAction";
+const char* labelColorPath       = SETTINGS_PATH_PREFIX "/ColorLabels/color_";
+const char* labelTextPath        = SETTINGS_PATH_PREFIX "/ColorLabels/text_";
+const char* lastEditedSetpath    = SETTINGS_PATH_PREFIX "/Environment/LastEdited";
+const char* autoSave             = SETTINGS_PATH_PREFIX "/Environment/autoSave";
+const char* expandTreeSetpath    = SETTINGS_PATH_PREFIX "/UI/ExpandTree";
+const char* MergeLibsSetpath     = SETTINGS_PATH_PREFIX "/UI/MergeLibraries";
+const char* infoStyleSetpath     = SETTINGS_PATH_PREFIX "/UI/InfoWindowStyle";
+const char* infoWindowHSetpath   = SETTINGS_PATH_PREFIX "/UI/InfoWindowHeight";
+const char* groupModeSetpath     = SETTINGS_PATH_PREFIX "/UI/GroupViewMode";
+const char* groupColsSetpath     = SETTINGS_PATH_PREFIX "/UI/GroupViewColumns";
+const char* objTooltips          = SETTINGS_PATH_PREFIX "/UI/objTooltips";
+const char* tooltipDelay         = SETTINGS_PATH_PREFIX "/UI/tooltipDelay";
+const char* emptyRCSLog          = SETTINGS_PATH_PREFIX "/RCS/emptyLog";
+const char* dontSaveStdLib       = SETTINGS_PATH_PREFIX "/DataFormat/dontSaveStdLib";
+const char* WindowGeometrySetpath= SETTINGS_PATH_PREFIX "/Layout/";
+const char* screenPositionSetpath= SETTINGS_PATH_PREFIX "/ScreenPos/";
 
-const char* SSHPath              = "/FirewallBuilder2/SSH/SSHPath";
-const char* SCPPath              = "/FirewallBuilder2/SSH/SCPPath";
+const char* SSHPath              = SETTINGS_PATH_PREFIX "/SSH/SSHPath";
 
 FWBSettings::FWBSettings() : QSettings()
 {
@@ -179,46 +178,45 @@ void FWBSettings::init()
     { setLabelColor(GRAY  ,"#C0C0C0"); setLabelText(GRAY  ,"Gray"); }
 
 #ifndef _WIN32
-    if (getSCPPath().isEmpty())  setSCPPath("scp");
     if (getSSHPath().isEmpty())  setSSHPath("ssh");
 #endif
 }
 
 QString FWBSettings::getStr(const QString &attribute)
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     return readEntry(path);
 }
 
 void    FWBSettings::setStr(const QString &attribute,
                             const QString &val)
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     writeEntry(path,val);
 }
 
 bool    FWBSettings::getBool(const QString &attribute)
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     return readBoolEntry(path);
 }
 
 void    FWBSettings::setBool(const QString &attribute, bool val )
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     writeEntry(path,val);
 }
 
     
 int     FWBSettings::getInt(const QString &attribute)
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     return readNumEntry(path);
 }
 
 void    FWBSettings::setInt(const QString &attribute, int val )
 {
-    QString path="/FirewallBuilder2/"+attribute;
+    QString path=SETTINGS_PATH_PREFIX "/"+attribute;
     writeEntry(path,val);
 }
 
@@ -280,7 +278,7 @@ void    FWBSettings::setSaveFileDir( const QString &d )
 
 void    FWBSettings::save()
 {
-    setLastEdited( FWObjectDatabase::db->getFileName().c_str() );
+    setLastEdited( mw->db()->getFileName().c_str() );
 
     if (getInfoStyle()!=0) setInfoWindowHeight(oi->geometry().height());
 }
@@ -484,16 +482,6 @@ void    FWBSettings::setLabelText(enum LabelColors c, const QString &s)
     writeEntry(QString(labelTextPath) + getLabelColorStr(c),s);
 }
 
-QString FWBSettings::getSCPPath()
-{
-    return readEntry(SCPPath);
-}
-
-void    FWBSettings::setSCPPath(const QString &path)
-{
-    writeEntry(SCPPath,path);
-}
-    
 QString FWBSettings::getSSHPath()
 {
     return readEntry(SSHPath);
