@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindowPrint.cpp,v 1.23 2006/10/22 04:39:36 vkurland Exp $
+  $Id: FWWindowPrint.cpp,v 1.24 2007/06/21 05:43:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,6 +57,7 @@
 #include "fwbuilder/Policy.h"
 #include "fwbuilder/InterfacePolicy.h"
 #include "fwbuilder/NAT.h"
+#include "fwbuilder/Routing.h"
 #include "fwbuilder/Interface.h"
 
 #include "fwbuilder/Library.h"
@@ -168,6 +169,9 @@ list<FWObject*> findAllUsedByType(list<FWObject*> &result,FWObject *obj,const st
         ruleSet = obj->getFirstByType(NAT::TYPENAME);
         findAllUsedByType(result,ruleSet,typeName);
 
+        ruleSet = obj->getFirstByType(Routing::TYPENAME);
+        findAllUsedByType(result,ruleSet,typeName);
+
         result.sort();
         result.unique();
     }
@@ -192,9 +196,14 @@ int addObjectsToTable(list<FWObject*> &objects,
         if (Service::cast(*i)!=NULL && Service::cast(*i)->isAny()) continue;
         if (Interval::cast(*i)!=NULL && Interval::cast(*i)->isAny()) continue;
 
+        if (col>=tbl->numCols())
+        {
+            col = 0;
+            row++;
+            tbl->insertRows(row,1);
+        }
+
         string typeName = (*i)->getTypeName();
-//        QPixmap pm = QPixmap::fromMimeSource( Resources::global_res->getResourceStr(
-//                                                icon_path+typeName+"/icon").c_str());
 
         QString icn = Resources::global_res->getResourceStr(
             icon_path+typeName+"/icon").c_str();
@@ -211,22 +220,14 @@ int addObjectsToTable(list<FWObject*> &objects,
         tbl->setPixmap(row,col,bfr);
         tbl->setText(row,col, QString::fromUtf8((*i)->getName().c_str()));
 
-/*
-        QString descr = FWObjectPropertiesFactory::getObjectPropertiesDetailed(*i,
-                                                                               true,
-                                                                               true,
-                                                                               true);
-        QTextView tv;
-        tv.resize(250,250);
-        tv.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
-        tv.setTextFormat(QTextEdit::RichText);
-        tv.append(descr);
-        tbl->setPixmap(row,col+1,QPixmap::grabWidget(&tv,0,0));
-*/
-
         QString descr = FWObjectPropertiesFactory::getObjectProperties(*i);
         QString comment =  QString::fromUtf8((*i)->getComment().c_str());
 
+        // collapse paragraphs
+        //comment.replace("\n\n", "&#10;");
+        //comment.replace("\n", "");
+        //comment.replace("&#10;", "\n");
+
         tbl->setText(row,col+1, descr);
         tbl->setText(row,col+2, comment);
         tbl->item(row,col+2)->setWordWrap(true);
@@ -234,15 +235,10 @@ int addObjectsToTable(list<FWObject*> &objects,
         added++;
 
         if (fwbdebug)
-            qDebug("objTbl: row=%d col=%d '%s'",row,col,(*i)->getName().c_str());
+            qDebug("objTbl: row=%d col=%d '%s'",
+                   row, col, (*i)->getName().c_str());
 
         col = col+3;
-        if (col>=tbl->numCols())
-        {
-            col = 0;
-            row++;
-            tbl->insertRows(row,1);
-        }
     }
     return added;
 }
@@ -289,7 +285,7 @@ void printFirewall(FWObject *fw,
     pr.printText(" ");
 
 //            ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing global policy"));
-    if (fwbdebug)  qDebug("Global policy");
+    if (fwbdebug)  qDebug("******** Global policy");
 
     pr.printText(QObject::tr("Global Policy"));
 
@@ -331,7 +327,8 @@ void printFirewall(FWObject *fw,
             tabName=QString::fromUtf8(intf->getName().c_str());
 
 //                ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing policy for interface %1").arg(tabName));
-          if (fwbdebug)  qDebug("Interface policy for %s",tabName.latin1());
+          if (fwbdebug)
+              qDebug("******** Interface policy for %s",tabName.latin1());
 
 
           if (newPageForSection)
@@ -358,30 +355,59 @@ void printFirewall(FWObject *fw,
     }
 
 //            ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing NAT rules"));
-    if (fwbdebug)  qDebug("NAT");
-
-    if (newPageForSection)
-    {
-        pr.flushPage();
-        pr.beginPage();   // resets yPos
-    } else
-        pr.printText(" ");
-
-    pr.printText(QObject::tr("NAT"));
-
+    if (fwbdebug)  qDebug("******** NAT");
     NAT *nat  = NAT::cast(fw->getFirstByType(NAT::TYPENAME));
-    ruleView=new NATView(nat,NULL);
+    if (nat && nat->size()!=0)
+    {
+        if (newPageForSection)
+        {
+            pr.flushPage();
+            pr.beginPage();   // resets yPos
+        } else
+            pr.printText(" ");
 
-    ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
-                                          (QSizePolicy::SizeType)7) );
-    ruleView->setHScrollBarMode(QScrollView::AlwaysOff);
-    ruleView->setVScrollBarMode(QScrollView::AlwaysOff);
+        pr.printText(QObject::tr("NAT"));
 
-    if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
+        ruleView=new NATView(nat,NULL);
 
-    pr.printQTable(ruleView);
+        ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
+                                              (QSizePolicy::SizeType)7) );
+        ruleView->setHScrollBarMode(QScrollView::AlwaysOff);
+        ruleView->setVScrollBarMode(QScrollView::AlwaysOff);
+
+        if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
+
+        pr.printQTable(ruleView);
 //    pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
-    delete ruleView;
+        delete ruleView;
+    }
+
+    if (fwbdebug)  qDebug("******** Routing");
+    Routing *routing  = Routing::cast(fw->getFirstByType(Routing::TYPENAME));
+    if (routing && routing->size()!=0)
+    {
+        if (newPageForSection)
+        {
+            pr.flushPage();
+            pr.beginPage();   // resets yPos
+        } else
+            pr.printText(" ");
+
+        pr.printText(QObject::tr("Routing"));
+
+        ruleView=new RoutingView(routing,NULL);
+
+        ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
+                                              (QSizePolicy::SizeType)7) );
+        ruleView->setHScrollBarMode(QScrollView::AlwaysOff);
+        ruleView->setVScrollBarMode(QScrollView::AlwaysOff);
+
+        if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
+
+        pr.printQTable(ruleView);
+//    pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
+        delete ruleView;
+    }
 }
 
 void FWWindow::filePrint()
@@ -503,6 +529,7 @@ void FWWindow::filePrint()
     
             if (printLegend)
             {
+                if (fwbdebug) qDebug("******** Legend");
 
                 if (newPageForSection)
                 {
@@ -515,6 +542,8 @@ void FWWindow::filePrint()
                 pr.printText(" ");
 
                 QTable legendTbl(1,2);
+                legendTbl.resize(pr.getWorkspaceWidth(),
+                                 pr.getWorkspaceHeight());
                 legendTbl.setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
                                                       (QSizePolicy::SizeType)7) );
                 legendTbl.setShowGrid(false);
@@ -583,13 +612,16 @@ void FWWindow::filePrint()
                 if (fwbdebug) qDebug("legendTbl size: %dx%d",
                                      legendTbl.width(),legendTbl.height());
 
-                pr.printQTable(&legendTbl);
+                pr.printQTable(&legendTbl, false, false);
             }
 
 /* *********** Objects ************** */
 
             if (printObjects)
             {
+                if (fwbdebug)
+                    qDebug("******** Objects");
+
                 if (newPageForSection)
                 {
                     pr.flushPage();
@@ -603,14 +635,17 @@ void FWWindow::filePrint()
                 bool haveObjGroups = false;
                 bool haveSrvGroups = false;
 
-                QTable objTbl(1,6);
-                objTbl.setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
-                                                   (QSizePolicy::SizeType)7) );
-                objTbl.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
-                objTbl.setTopMargin(0);
-                objTbl.setLeftMargin(0);
-                objTbl.setHScrollBarMode(QScrollView::AlwaysOff);
-                objTbl.setVScrollBarMode(QScrollView::AlwaysOff);
+                QTable fwObjTbl(1,3);
+                //fwObjTbl.setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
+                //                                 (QSizePolicy::SizeType)7) );
+                fwObjTbl.setColumnStretchable(2, true);
+                fwObjTbl.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
+                fwObjTbl.setTopMargin(0);
+                fwObjTbl.setLeftMargin(0);
+                fwObjTbl.setHScrollBarMode(QScrollView::AlwaysOff);
+                fwObjTbl.setVScrollBarMode(QScrollView::AlwaysOff);
+                fwObjTbl.resize(pr.getWorkspaceWidth(),
+                                pr.getWorkspaceHeight());
 
                 list<FWObject*> objects;
                 QString descr;
@@ -621,16 +656,31 @@ void FWWindow::filePrint()
 
                 objects.clear();
                 findAllUsedByType(objects,visibleFirewall,Firewall::TYPENAME);
-                added=addObjectsToTable(objects,&objTbl,row,col);
+                added = addObjectsToTable(objects, &fwObjTbl, row, col);
                 if (fwbdebug) qDebug("Objects table: added %d firewalls",added);
-                if (added)
-                {
-                    if (col!=0)
-                    {
-                        row++; col=0;
-                        objTbl.insertRows(row,1);
-                    }
-                }
+
+                for (int i=0; i<fwObjTbl.numCols(); ++i)
+                    fwObjTbl.adjustColumn(i);
+                for (int i=0; i<fwObjTbl.numRows(); ++i)
+                    fwObjTbl.adjustRow(i);
+
+                pr.printQTable(&fwObjTbl, false, false);
+                pr.printText(" ");
+
+                QTable objTbl(1,6);
+                objTbl.resize(pr.getWorkspaceWidth(),
+                              pr.getWorkspaceHeight());
+                objTbl.setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7,
+                                                   (QSizePolicy::SizeType)7) );
+                objTbl.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
+                objTbl.setTopMargin(0);
+                objTbl.setLeftMargin(0);
+                objTbl.setHScrollBarMode(QScrollView::AlwaysOff);
+                objTbl.setVScrollBarMode(QScrollView::AlwaysOff);
+
+                row = 0;
+                col = 0;
+                added = 0;
 
                 objects.clear();
                 findAllUsedByType(objects,visibleFirewall,Host::TYPENAME);
@@ -793,11 +843,13 @@ void FWWindow::filePrint()
                 for (int i=0; i<objTbl.numCols(); ++i) objTbl.adjustColumn(i);
                 for (int i=0; i<objTbl.numRows(); ++i) objTbl.adjustRow(i);
 
-                pr.printQTable(&objTbl);
+                pr.printQTable(&objTbl, false, false);
 //                pr.printPixmap(QPixmap::grabWidget(&objTbl,0,0));
 
                 if (haveObjGroups || haveSrvGroups)
                 {
+                    if (fwbdebug) qDebug("******** Groups");
+
                     pr.printText("\n");
                     pr.printText(tr("Groups"));
                     pr.printText(" ");
@@ -851,7 +903,7 @@ void FWWindow::filePrint()
                             objTbl.adjustRow(i);
 
                         pr.printText((*obj)->getName().c_str());
-                        pr.printQTable(&objTbl);
+                        pr.printQTable(&objTbl, false, false);
                         pr.printText("\n");
                     }
                 }
