@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.h,v 1.15 2006/05/13 06:53:05 vkurland Exp $
+  $Id: GroupObjectDialog.h,v 1.16 2006/08/18 04:10:33 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -45,7 +45,7 @@ class IconViewObjToolTip : public QToolTip {
     QIconView *view;
  public:
     IconViewObjToolTip(QIconView *w);
-
+    virtual ~IconViewObjToolTip() {}
     virtual void maybeTip(const QPoint &p);
 };
 
@@ -54,7 +54,7 @@ class ListViewObjToolTip : public QToolTip {
     QListView *view;
  public:
     ListViewObjToolTip(QListView *w);
-
+    virtual ~ListViewObjToolTip() {}
     virtual void maybeTip(const QPoint &p);
 };
 
