@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMPServiceDialog.cpp,v 1.25 2006/05/13 06:53:05 vkurland Exp $
+  $Id: ICMPServiceDialog.cpp,v 1.26 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -91,6 +91,8 @@ void ICMPServiceDialog::changed()
 void ICMPServiceDialog::validate(bool *res)
 {
     *res=true;
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void ICMPServiceDialog::isChanged(bool *res)
@@ -105,9 +107,6 @@ void ICMPServiceDialog::libChanged()
 
 void ICMPServiceDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     string oldname=obj->getName();
     obj->setName( string(obj_name->text().utf8()) );
     obj->setComment( string(comment->text().utf8()) );
