@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPServiceDialog.cpp,v 1.23 2006/05/13 06:53:05 vkurland Exp $
+  $Id: IPServiceDialog.cpp,v 1.24 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -114,6 +114,8 @@ void IPServiceDialog::changed()
 void IPServiceDialog::validate(bool *res)
 {
     *res=true;
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void IPServiceDialog::isChanged(bool *res)
@@ -128,9 +130,6 @@ void IPServiceDialog::libChanged()
 
 void IPServiceDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     string oldname=obj->getName();
     obj->setName( string(obj_name->text().utf8()) );
     obj->setComment( string(comment->text().utf8()) );
