@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPTImporter.cpp,v 1.8 2007/06/14 02:55:29 vkurland Exp $
+  $Id: IPTImporter.cpp,v 1.9 2007/08/06 07:07:22 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -294,8 +294,12 @@ FWObject* IPTImporter::createTCPUDPService(str_tuple &src_range,
     FWObject *o;
     if (proto=="tcp")
     {
-        o = getTCPService(srs,sre,drs,dre,established,tcp_flags_mask,tcp_flags_comp);
-    } else              o = getUDPService(srs,sre,drs,dre);
+        o = getTCPService(srs,sre,
+                          drs,dre,
+                          established,
+                          tcp_flags_mask,tcp_flags_comp);
+    } else
+        o = getUDPService(srs,sre,drs,dre);
     return o;
 }
 
@@ -402,6 +406,7 @@ void IPTImporter::pushPolicyRule()
     // populate all elements of the rule
 
     PolicyRule *rule = PolicyRule::cast(current_rule);
+    rule->setLogging(false);
 
     FWOptions  *fwopt = getFirewallObject()->getOptionsObject();
     assert(fwopt!=NULL);
@@ -430,13 +435,16 @@ void IPTImporter::pushPolicyRule()
         action = PolicyRule::Continue;
         rule->setLogging(true);
         ropt->setStr("log_prefix", action_params["log_prefix"]);
+        ropt->setStr("log_tcp_seq", action_params["log_tcp_seq"]);
+        ropt->setStr("log_tcp_options", action_params["log_tcp_options"]);
+        ropt->setStr("log_ip_options", action_params["log_ip_options"]);
         ropt->setStr("log_level", action_params["log_level"]);
         if (!limit_val.empty())
         {
-            fwopt->setStr("limit_value", limit_val);
-            fwopt->setStr("limit_suffix", std::string("/")+limit_suffix);
+            ropt->setStr("limit_value", limit_val);
+            ropt->setStr("limit_suffix", std::string("/")+limit_suffix);
             if (!limit_burst.empty())
-                fwopt->setStr("limit_burst", limit_burst);
+                ropt->setStr("limit_burst", limit_burst);
         }
     }
     if (target=="ULOG")
@@ -471,16 +479,59 @@ void IPTImporter::pushPolicyRule()
         ropt->setBool("ipt_continue", !action_params["route_continue"].empty());
         ropt->setBool("ipt_tee",      !action_params["route_tee"].empty());
     }
+    if (target=="RETURN")
+    {
+        action = PolicyRule::Continue;
+    }
 
     if (action==PolicyRule::Unknown)
     {
         // unknown target, consider it a branch
+        // NOTE:
+        // as of fwbuilder v2.1, branch ruleset is a child object of
+        // PolicyRule. This means two different rules can not point at the same
+        // branch ruleset. This is unfortunate. To fix this we need
+        // to change XML DTD and API. Will do this in 3.0
+        // Meanwhile, have to check if branch ruleset with requested name
+        // already exists and change the name by adding suffix '1', '2' etc
+        // to make it different.
+        //
+        std::string branch_ruleset_name = target;
+        bool duplicate_branch = false;
+        int cntr = 0;
         action = PolicyRule::Branch;
-        UnidirectionalRuleSet *rs = getUnidirRuleSet(target);  // creates if new
-        assert(rs!=NULL);
+        UnidirectionalRuleSet *rs = NULL;
+        while (true)
+        {
+            rs = branch_rulesets[branch_ruleset_name];
+            if (rs==NULL)
+            {
+                rs = getUnidirRuleSet(branch_ruleset_name);
+                break;
+            } else
+            {
+                std::ostringstream ostr;
+                ostr << ++cntr;
+                branch_ruleset_name = target + ostr.str();
+                duplicate_branch = true;
+            }
+        }
+
         current_rule->add(rs->ruleset);
-        ropt->setStr("branch_name", target);
+        ropt->setStr("branch_name", branch_ruleset_name);
         getFirewallObject()->remove(rs->ruleset, false);
+        branch_rulesets[branch_ruleset_name] = rs;
+        
+        if (duplicate_branch)
+            markCurrentRuleBad(
+                std::string("Rule passes control to branch ") + target + 
+                std::string(
+                    " which \n"
+                    "is already used by some rule prior to this one. \n"
+                    "fwbuilder 2.1 does not support multiple rules \n"
+                    "passing control to the same branch. This will \n"
+                    "be fixed in the next major release (v3.0)"));
+
     }
 
     rule->setAction(action);
@@ -789,13 +840,7 @@ Firewall* IPTImporter::finalize()
     // UnidirectionalRuleSet into one RuleSet object. Attach this
     // object to the firewall.
 
-    // Add progress print to debug_output instead of using qDebug
-    // so it can be used for unit tests
-
-    std::ostringstream dbg;
-
-    dbg << "\n";
-    dbg << "******************************** FINALIZE:" << "\n";
+    if (fwbdebug) qDebug("IPTImporter::finalize()");
 
     if (haveFirewallObject())
     {
@@ -844,8 +889,6 @@ Firewall* IPTImporter::finalize()
             delete rs->ruleset;
         }
 
-        debug_output += dbg.str();
-
         return getFirewallObject();
     }
     else
