@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibExportDialog.cpp,v 1.17 2006/07/13 04:59:22 vkurland Exp $
+  $Id: LibExportDialog.cpp,v 1.18 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -50,6 +50,7 @@
 #include <qmessagebox.h>
 #include <qapplication.h>
 #include <qcursor.h>
+#include <qpixmapcache.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -90,10 +91,18 @@ void LibExportDialog::init()
             libicn=Resources::global_res->getObjResourceStr(*i,"icon-tree").c_str();
 
         mapOfLibs[n]= (*i);
-        libs->insertItem(
-            QPixmap::fromMimeSource( libicn.c_str() ),
-            QString::fromUtf8((*i)->getName().c_str()),
-            n);
+
+        QPixmap pm;
+        QString icn = libicn.c_str();
+        if ( ! QPixmapCache::find( icn, pm) )
+        {
+            pm = QPixmap::fromMimeSource( icn );
+            QPixmapCache::insert( icn, pm);
+        }
+
+        libs->insertItem(pm,
+                         QString::fromUtf8((*i)->getName().c_str()),
+                         n);
     }
 
 }
