@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibraryDialog.cpp,v 1.29 2006/10/22 04:39:36 vkurland Exp $
+  $Id: LibraryDialog.cpp,v 1.30 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -107,9 +107,6 @@ void LibraryDialog::changeIds(FWObject *root)
 
 void LibraryDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     string oldname=obj->getName();
     QString oldcolor=obj->getStr("color").c_str();
     obj->setName( string(obj_name->text().utf8()) );
@@ -137,6 +134,8 @@ void LibraryDialog::discardChanges()
 void LibraryDialog::validate(bool *res)
 {
     *res=true;
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void LibraryDialog::isChanged(bool *res)
