@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectEditor.cpp,v 1.43 2006/09/07 15:42:12 vkurland Exp $
+  $Id: ObjectEditor.cpp,v 1.44 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -435,8 +435,8 @@ bool ObjectEditor::validateAndSave()
         switch ( QMessageBox::warning(dialogs[ visible ],
                                       "Firewall Builder",
                                       tr("Modifications done to this object can not be saved.\nDo you want to continue editing it ?"),
-                                      tr("&Edit"),
-                                      tr("&Discard"),
+                                      tr("&Continue editing"),
+                                      tr("&Discard changes"),
                                       QString::null,
                                       0, 1 ) )
         {
@@ -504,9 +504,14 @@ void ObjectEditor::close()
 
 void ObjectEditor::apply()
 {
-    emit applyChanges_sign();
-    applyButton->setEnabled(false);
-    mw->updateRuleSetView( );
+    bool isgood=true;
+    emit validate_sign( &isgood );
+    if (isgood)
+    {
+        emit applyChanges_sign();
+        applyButton->setEnabled(false);
+        mw->updateRuleSetView( );
+    }
 }
 
 void ObjectEditor::discard()
