@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.cpp,v 1.161 2007/01/10 06:28:51 vkurland Exp $
+  $Id: ObjectManipulator.cpp,v 1.164 2007/07/07 05:39:34 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "config.h"
 #include "global.h"
 #include "utils.h"
+#include "utils_no_qt.h"
 
 #include "ObjectManipulator.h"
 #include "ObjectEditor.h"
@@ -219,6 +220,7 @@ QString ObjectManipulator::getTreeLabel( FWObject *obj )
         if (Interface::constcast(obj)->isUnnumbered()) q=" unnum";
         if (Interface::constcast(obj)->isBridgePort()) q=" bridge port";
         if (Interface::constcast(obj)->isExt())        q=q+" ext";
+        if (Interface::constcast(obj)->isUnprotected())q=q+" unp";
         if (q!="") name=name+" ("+q+")";
     }
     else
@@ -252,6 +254,8 @@ ObjectTreeViewItem* ObjectManipulator::insertObject( ObjectTreeViewItem *itm,
     else
         icn_filename=Resources::global_res->getObjResourceStr(obj, "icon-tree").c_str();
 
+    if (obj->getBool("ro")) icn_filename = "lock.png";
+
     if (Resources::global_res->getResourceBool(
             string("/FWBuilderResources/Type/") +
             obj->getTypeName() + "/hidden") ) return NULL;
@@ -1657,7 +1661,11 @@ void ObjectManipulator::lockObject()
     for (vector<FWObject*>::iterator i=so.begin();  i!=so.end(); ++i)
     {
         obj= *i;
-        obj->setReadOnly(true);
+        FWObject *lib = obj->getLibrary();
+        // these lbraries are locked anyway, do not let the user
+        // lock objects inside because they won't be able to unlock them.
+        if (lib->getId()!=STANDARD_LIB && lib->getId()!=TEMPLATE_LIB)
+            obj->setReadOnly(true);
     }
     getCurrentObjectTree()->setLockFlags();
     getCurrentObjectTree()->updateTreeItems();
@@ -1677,7 +1685,9 @@ void ObjectManipulator::unlockObject()
     for (vector<FWObject*>::iterator i=so.begin();  i!=so.end(); ++i)
     {
         obj= *i;
-        obj->setReadOnly(false);
+        FWObject *lib = obj->getLibrary();
+        if (lib->getId()!=STANDARD_LIB && lib->getId()!=TEMPLATE_LIB)
+            obj->setReadOnly(false);
     }
     getCurrentObjectTree()->setLockFlags();
     getCurrentObjectTree()->updateTreeItems();
