@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.h,v 1.19 2006/09/15 05:48:21 vkurland Exp $
+  $Id: ObjectTreeView.h,v 1.22 2007/01/08 03:37:53 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,6 +52,10 @@ class ObjectTreeView : public QListView {
     bool             Lockable;
     bool             Unlockable;
 
+    bool             visible;
+
+    bool             process_mouse_release_event;
+
     std::vector<libfwbuilder::FWObject*>          selectedObjects;
         
  protected:
@@ -92,7 +96,10 @@ class ObjectTreeView : public QListView {
     void editCurrentObject();
 
     void clearLastSelected();
-    
+
+    void becomingVisible() { visible=true; }
+    void becomingHidden()  { visible=false; }
+
 /* Under some circumstances, user may select several host or fw
  * objects so that their children objects are selected as well
  * (e.g. when shift-click is used). "Delete objects" or "group
@@ -103,6 +110,8 @@ class ObjectTreeView : public QListView {
  * actions.
  */
     std::vector<libfwbuilder::FWObject*> getSimplifiedSelection();
+
+    void ignoreNextMouseReleaseEvent() { process_mouse_release_event = false; }
     
  public slots:
 
