@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrefsDialog.cpp,v 1.28 2006/10/22 04:39:36 vkurland Exp $
+  $Id: PrefsDialog.cpp,v 1.29 2007/02/04 04:20:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -262,11 +262,14 @@ void PrefsDialog::libClick(QListViewItem* itm, const QPoint &p, int col)
 
                 i->load = !i->load;
 
+#if 0
+// commented out for bug #1620284
                 if (i->load)
                 {
                     mw->loadLibrary( i->path.latin1() );
                     om->loadObjects();
                 }
+#endif
                 break;
             }
         }
@@ -301,8 +304,10 @@ void PrefsDialog::addLibrary()
         }
         itm->setPixmap(1, pm);
 
-        mw->loadLibrary( i->path.latin1() );
-        om->loadObjects();
+        // commented out for bug #1620284
+        //
+        //mw->loadLibrary( i->path.latin1() );
+        //om->loadObjects();
     }
 }
 
