@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.h,v 1.20 2005/05/29 01:13:35 vkurland Exp $
+  $Id: RCS.h,v 1.21 2006/07/19 06:21:08 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -113,6 +113,11 @@ class RCS : public QObject {
     bool                  temp;         // if filename is a temporary file
     QValueList<Revision>  revisions;
 
+    /**
+     * Retrieves RCS log.
+     */
+    QString rlog() throw(libfwbuilder::FWException);
+
  public:
 
     RCS( const QString &filename );
@@ -156,11 +161,6 @@ class RCS : public QObject {
      */
     bool  ci(const QString &logmsg =" ", bool unlock=false) throw(libfwbuilder::FWException);
 
-    /**
-     * Retrieves RCS log.
-     */
-    QStringList rlog() throw(libfwbuilder::FWException);
-
     /**
      * Retrieves RCS diff.
      */
