@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp,v 1.22 2007/04/14 01:48:51 vkurland Exp $
+  $Id: RuleOptionsDialog.cpp,v 1.24 2007/07/14 21:08:42 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -84,6 +84,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     if (platform=="pf")       wid=2;
     if (platform=="ipfw")     wid=3;
     if (platform=="pix" || platform=="fwsm")      wid=4;
+    if (platform=="iosacl")   wid=5;
 
     wStack->raiseWidget( wid );
     wStack->widget(wid)->show();
@@ -147,6 +148,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     {
         data.registerOption( pf_logPrefix        , ropt,  "log_prefix" );
         data.registerOption( pf_stateless        , ropt,  "stateless" );
+        data.registerOption( pf_keep_state       , ropt,  "pf_keep_state" );
         data.registerOption( pf_rule_max_state   , ropt,  "pf_rule_max_state" );
         data.registerOption( pf_source_tracking  , ropt,  "pf_source_tracking" );
         data.registerOption( pf_max_src_nodes    , ropt,  "pf_max_src_nodes" );
