@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.cpp,v 1.17 2006/09/17 05:15:50 vkurland Exp $
+  $Id: SSHPIX.cpp,v 1.23 2007/07/13 05:32:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -83,7 +83,16 @@ SSHPIX::SSHPIX(QWidget *_par,
     errorsEnabledState.push_back("invalid");
     errorsEnabledState.push_back("cannot find");
     errorsEnabledState.push_back("An object-group with the same id but different type");
+}
 
+void SSHPIX::loadPreConfigCommands(const QStringList &cl)
+{
+    pre_config_commands = cl;
+}
+
+void SSHPIX::loadPostConfigCommands(const QStringList &cl)
+{
+    post_config_commands = cl;
 }
 
 SSHPIX::~SSHPIX()
@@ -94,18 +103,18 @@ QString SSHPIX::cmd(QProcess *proc,const QString &cmd)
 {
     stdoutBuffer="";
 
-    proc->writeToStdin( cmd  );
-    proc->writeToStdin( "\n" );
+    proc->writeToStdin( cmd + "\n"  );
+//    proc->writeToStdin( "\n" );
 
     state=EXECUTING_COMMAND;
-    QApplication::eventLoop()->enterLoop();
+    qApp->processEvents();
+//    QApplication::eventLoop()->enterLoop();
 
     return stdoutBuffer;
 }
 
 
-
-void SSHPIX::stateMachine()
+bool SSHPIX::checkForErrors()
 {
     QStringList *errptr;
 
@@ -129,11 +138,16 @@ void SSHPIX::stateMachine()
             stdoutBuffer="";
 //            terminate();
             sessionComplete(true);   // finish with error status
-            return;
+            return true;
         }
     }
+    return false;
+}
+
+void SSHPIX::stateMachine()
+{
+    if (checkForErrors()) return;
 
- entry:
     switch (state)
     {
     case NONE:
@@ -141,8 +155,8 @@ void SSHPIX::stateMachine()
         if ( cmpPrompt(stdoutBuffer,QRegExp(pwd_prompt)) )
         {
             stdoutBuffer="";
-            proc->writeToStdin( pwd );
-            proc->writeToStdin( "\n" );
+            proc->writeToStdin( pwd + "\n" );
+            // proc->writeToStdin( "\n" );
             break;
         }
 /* we may get to LOGGEDIN state directly from NONE, for example when
@@ -150,27 +164,41 @@ void SSHPIX::stateMachine()
  */
         if (cmpPrompt(stdoutBuffer,QRegExp(normal_prompt)) )
         {
+            stdoutBuffer="";
             state=LOGGEDIN;
             emit printStdout_sign( "\n");
             emit printStdout_sign( tr("Logged in") + "\n" );
             emit printStdout_sign( tr("Switching to enable mode...") + "\n");
             stdoutBuffer="";
             proc->writeToStdin( "enable\n" );
+            //proc->writeToStdin( "\n" );
+        }
+
+/* we may even get straight to the enable prompt, e.g. if
+ * user account is configured with "privilege 15"
+ */
+        if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
+        {       
+            state=WAITING_FOR_ENABLE;
+            stateMachine();
+            break;
         }
 
         QString fingerprint;
         int n1,n2;
         if (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
-            stdoutBuffer.find(newKeyPlink)!=-1)
+            stdoutBuffer.find(newKeyPlink)!=-1   ||
+            stdoutBuffer.find(newKeySSHComm)!=-1)
         {
 /* new key */
+            bool unix_y_n = (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
+                             stdoutBuffer.find(newKeySSHComm)!=-1);
+
             if (fwbdebug) qDebug("New host key message detected");
 
-            n1=stdoutBuffer.find(fingerprintPrompt) + strlen(fingerprintPrompt);
-            n2=stdoutBuffer.find(QRegExp("[^ 0-9a-f:]"), n1+4);
-            fingerprint=stdoutBuffer.mid(n1,n2-n1);
+            fingerprint = findKeyFingerprint(stdoutBuffer);
 
-            QString msg=newKeyMsg.arg(host).arg(fingerprint).arg(host);
+            QString msg = newKeyMsg.arg(host).arg(fingerprint).arg(host);
 
             stopHeartBeat();
 
@@ -186,7 +214,8 @@ void SSHPIX::stateMachine()
             stdoutBuffer="";
             if (res==0)
             {
-                proc->writeToStdin( "yes\n" );
+                if (unix_y_n) proc->writeToStdin( "yes\n" );
+                else          proc->writeToStdin( "y\n" );
                 break;
             } else
             {
@@ -203,8 +232,8 @@ void SSHPIX::stateMachine()
         if ( cmpPrompt(stdoutBuffer,QRegExp(epwd_prompt)) )
         {
             stdoutBuffer="";
-            if (!epwd.isEmpty()) proc->writeToStdin( epwd );
-            proc->writeToStdin( "\n" );
+            if (!epwd.isEmpty()) proc->writeToStdin( epwd + "\n" );
+            else                 proc->writeToStdin( "\n" );
             state=WAITING_FOR_ENABLE;
         }
         break;
@@ -213,8 +242,8 @@ void SSHPIX::stateMachine()
         if ( cmpPrompt(stdoutBuffer,QRegExp(epwd_prompt)) )
         {
             stdoutBuffer="";
-            if (!epwd.isEmpty()) proc->writeToStdin( epwd );
-            proc->writeToStdin( "\n" );
+            if (!epwd.isEmpty()) proc->writeToStdin( epwd + "\n" );
+            else                 proc->writeToStdin( "\n" );
             state=WAITING_FOR_ENABLE;
             break;
         }
@@ -223,32 +252,79 @@ void SSHPIX::stateMachine()
             emit printStdout_sign( tr("In enable mode."));
             emit printStdout_sign( "\n");
             state=ENABLE;  // and go to ENABLE target in switch
+
+            /* give classes derived from SSHPIX a chance to do
+             * something before we switch to config mode. If <this> is
+             * SSHPIX class, the stateMachine method will simply call
+             * itself and will fall through to the ENABLE state.
+             */
+            stateMachine();
+            break;
         }
 
     case ENABLE:
         if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
         {
+            if (pre_config_commands.size()>0)
+            {
+                stdoutBuffer="";
+
+                QString cmd = pre_config_commands.front();
+                pre_config_commands.pop_front();
+
+                if (cmd.find("reload in")!=-1)
+                    state = SCHEDULE_RELOAD_DIALOG;
+
+                proc->writeToStdin( cmd + "\n" );
+                // proc->writeToStdin( "\n" );
+                break;
+            }
+
             stdoutBuffer="";
 
             if (backup)
             {
-/* the problem is that QProcess uses select and thus is tightly
- * integrated into event loop. QT uses internal private flag inside
- * QProcess to specifically prevent recursive calls to readyReadStdout
- * (look for d->socketReadCalled in kernel/qprocess_unix.cpp ). So, I
- * _must_ exit this callback before I can send commands to the process
- * and collect the output.
- */
+                /* the problem is that QProcess uses select and thus
+                 * is tightly integrated into event loop. QT uses
+                 * internal private flag inside QProcess to
+                 * specifically prevent recursive calls to
+                 * readyReadStdout (look for d->socketReadCalled in
+                 * kernel/qprocess_unix.cpp ). So, I _must_ exit this
+                 * callback before I can send commands to the process
+                 * and collect the output.
+                 */
                 QTimer::singleShot( 0, this, SLOT(PIXbackup()) );
                 break;
             }
 
-            proc->writeToStdin( "config t" );
-            proc->writeToStdin( "\n" );
+            proc->writeToStdin( "config t\n" );
+            //proc->writeToStdin( "\n" );
             state=WAITING_FOR_CONFIG_PROMPT;
         }
         break;
 
+    case SCHEDULE_RELOAD_DIALOG:
+        if ( cmpPrompt(stdoutBuffer,QRegExp("System config.* modified\\. Save?")) )
+        {
+            stdoutBuffer="";
+            proc->writeToStdin( "n" );  // no \n needed
+            break;
+        }
+        if ( cmpPrompt(stdoutBuffer,QRegExp("Proceed with reload?")) )
+        {
+            stdoutBuffer="";
+            proc->writeToStdin( "y" );  // no \n needed
+            break;
+        }
+        if ( cmpPrompt(stdoutBuffer,QRegExp("SHUTDOWN")) )
+        {
+            stdoutBuffer="";
+            proc->writeToStdin( "\n" );
+            state = ENABLE;
+            break;
+        }
+        break;
+
     case EXECUTING_COMMAND:
         if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
         {       
@@ -345,8 +421,8 @@ void SSHPIX::stateMachine()
                     if (s.find("! Rule ")!=-1)  rl=s.mid(7);
                     if ( !rl.isEmpty())
                     {
-                        emit printStdout_sign( tr("Rule %1").arg(rl) );
-                        emit printStdout_sign( "\n");
+                        emit printStdout_sign( tr("Rule %1").arg(rl) + "\n" );
+                        //emit printStdout_sign( "\n");
                     }
                 }
 
@@ -355,6 +431,7 @@ void SSHPIX::stateMachine()
                     if ( !s.isEmpty())  ncmd++;
                     stdoutBuffer="";
                     proc->writeToStdin( s+"\n"); // send even if s is empty
+                    qApp->processEvents();
                     break;
                 } else
                 {
@@ -409,47 +486,24 @@ void SSHPIX::stateMachine()
     case EXIT_FROM_CONFIG:
         if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
         {
-/*
- * dry_run means run through the commands without executing them on
- * the firewall
- *
- * testRun means executing commands on the firewall without storing
- * them permanently (i.e. do not do "wr mem")
- */
-            if (!dry_run && !testRun && ncmd!=0)
+            /*
+             * NOTE: at this point we are still in the config mode!
+             *
+             * Execute post_config_commands and exit from config mode.
+             */
+            if (post_config_commands.size()>0)
             {
-                emit printStdout_sign( tr("Save configuration") + "\n" );
-                state=SAVE_CONFIG;
-                proc->writeToStdin( "wr mem\n");
-            } else
-            {
-                state=EXIT;
-                proc->writeToStdin( "exit\n");
-            }
-        }
-        break;
+                stdoutBuffer="";
 
-    case SAVE_CONFIG:
-        if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
-        {
-            if (saveStandby && ncmd!=0)
-            {
-                emit printStdout_sign( tr("Save configuration to standby unit") + "\n" );
-                state=SAVE_STANDBY;
-                proc->writeToStdin( "wr standby\n");
-            } else
-            {
-                emit printStdout_sign( tr("Exiting") + "\n" );
-                state=EXIT;
-                proc->writeToStdin( "exit\n");
-            }
-        }
-        break;
+                QString cmd = post_config_commands.front();
+                post_config_commands.pop_front();
 
-    case SAVE_STANDBY:
-        if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
-        {
-            emit printStdout_sign( tr("Exiting") + "\n" );
+                proc->writeToStdin( cmd + "\n" );
+                //proc->writeToStdin( "\n" );
+                break;
+            }
+
+            stdoutBuffer="";
             state=EXIT;
             proc->writeToStdin( "exit\n");
         }
