@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp,v 1.23 2006/09/17 05:15:50 vkurland Exp $
+  $Id: SSHSession.cpp,v 1.27 2007/07/13 05:32:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,6 +40,8 @@
 #include <qeventloop.h>
 #include <qcstring.h>
 #include <qtextcodec.h>
+#include <qapplication.h>
+#include <qdatetime.h>
 
 #include <iostream>
 
@@ -53,7 +55,11 @@ using namespace std;
 char  *SSHSession::newKeyOpenSSH  ="Are you sure you want to continue connecting (yes/no)?";
 char  *SSHSession::newKeyPlink    ="Store key in cache? (y/n)";
 char  *SSHSession::newKeyVsh      ="Accept and save? (y/n)";
-char  *SSHSession::fingerprintPrompt="key fingerprint is";
+char  *SSHSession::newKeySSHComm  ="You can get a public key's fingerprint by running";
+
+
+char  *SSHSession::fingerprintPrompt1="key fingerprint is";
+char  *SSHSession::fingerprintPrompt2="Key fingerprint:";
 
 
 
@@ -101,6 +107,23 @@ SSHSession::SSHSession(QWidget *_par,
 
 }
 
+QString SSHSession::findKeyFingerprint(QString &buffer)
+{
+    char *fp = fingerprintPrompt1;
+    int n1,n2;
+
+    if ( (n1=buffer.find(fp))==-1)
+    {        
+        fp = fingerprintPrompt2;
+        if ( (n1=buffer.find(fp))==-1)
+            return QString("");
+    }
+
+    n1 += strlen(fp)+1;
+    n2 = buffer.find("\n", n1+4);
+    return buffer.mid(n1,n2-n1);
+}
+
 void SSHSession::startSession()
 {
     proc = new QProcess();
@@ -239,6 +262,11 @@ void SSHSession::terminate()
     if (fwbdebug) qDebug("SSHSession::terminate   done");
 }
 
+bool SSHSession::checkForErrors()
+{
+    return true;
+}
+
 void SSHSession::stateMachine()
 {
 }
@@ -345,8 +373,20 @@ void SSHSession::readFromStdout()
 {
     if (proc)
     {
-        QString buf = proc->readStdout();
-        stdoutBuffer=stdoutBuffer + buf;
+        if (fwbdebug)
+        {
+            QTime t = QTime::currentTime();
+            qDebug(QString("SSHSession::readFromStdout()  on entry: %1").
+                   arg(t.toString("hh:mm:ss.zzz")));
+        }
+
+        QByteArray ba = proc->readStdout();
+        int  basize  = ba.size();
+        if (basize==0) return;
+
+        QString buf(ba);
+
+        stdoutBuffer.append(buf);
 
         bool endsWithLF = buf.endsWith("\n");
         QString lastLine = "";
@@ -356,10 +396,21 @@ void SSHSession::readFromStdout()
 
         if (fwbdebug)
         {
-            qDebug("buf=%s",buf.ascii());
+            QTime t = QTime::currentTime();
+            qDebug(QString("SSHSession::readFromStdout()  on check 1: %1").
+                   arg(t.toString("hh:mm:ss.zzz")));
+        }
+
+#if 0
+        if (fwbdebug)
+        {
+            qDebug("- - - - - - - - - - - - - - - - - - - - - - - - - -");
+            qDebug("basize='%d'",basize);
+            qDebug("buffer='%s'",buf.ascii());
             qDebug("endsWithLF=%d",endsWithLF);
             qDebug("bufLines.size()=%d",bufLines.size());
         }
+#endif
 
         // if buf ends with a LF character, the last element in the list is
         // an empty string
@@ -387,28 +438,22 @@ void SSHSession::readFromStdout()
 
         pendingLogLine += lastLine;
 
+        if (fwbdebug)
+        {
+            QTime t = QTime::currentTime();
+            qDebug(QString("SSHSession::readFromStdout()  on check 2: %1").
+                   arg(t.toString("hh:mm:ss.zzz")));
+        }
+
         stateMachine();
 
-
-#if 0
-        QByteArray ba = proc->readStdout();
-        if (ba.size()!=0)
+        if (fwbdebug)
         {
-            if (fwbdebug)
-                qDebug("SSHSession::readFromStdout read %d bytes from child process",ba.size());
-            QString s=QString(ba);
-            stdoutBuffer=stdoutBuffer + s;
-
-            if (!quiet)
-            {
-                s.replace('\r',"");    
-                emit printStdout_sign(s);
-            }
-
-/* state machine operates on stdoutBuffer directly */
-            stateMachine();
+            QTime t = QTime::currentTime();
+            qDebug(QString("SSHSession::readFromStdout()  finish: %1").
+                   arg(t.toString("hh:mm:ss.zzz")));
         }
-#endif
+
     }
 }
 
