@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.cpp,v 1.20 2007/04/25 05:34:21 vkurland Exp $
+  $Id: SSHUnx.cpp,v 1.24 2007/07/13 05:32:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -67,6 +67,7 @@ SSHUnx::SSHUnx(QWidget *_par,
 
     errorsLoggedin.push_back("No such file or directory");
     errorsLoggedin.push_back("Cannot allocate memory");
+    errorsLoggedin.push_back("pfctl: Syntax error in config file:");
 
     iptables_errors.push_back("'iptables --help' for more information.");
     iptables_errors.push_back("'iptables-restore --help' for more information.");
@@ -101,22 +102,29 @@ bool SSHUnx::checkForErrors(QStringList *errptr)
     return false;
 }
 
-void SSHUnx::stateMachine()
+bool SSHUnx::checkForErrors()
 {
     switch (state)
     {
     case LOGGEDIN:
-        if (checkForErrors(&errorsLoggedin)) return;
+        if (checkForErrors(&errorsLoggedin)) return true;
         break;
 
     default:
-        if (checkForErrors(&errorsInit)) return;
+        if (checkForErrors(&errorsInit)) return true;
         break;
     }
 
-    if (checkForErrors(&iptables_errors)) return;
+    if (checkForErrors(&iptables_errors)) return true;
 
- entry:
+    return false;
+}
+
+void SSHUnx::stateMachine()
+{
+    if (checkForErrors()) return;
+
+    //entry:
     switch (state)
     {
     case NONE:
@@ -152,15 +160,16 @@ void SSHUnx::stateMachine()
         int n1,n2;
         if (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
             stdoutBuffer.find(newKeyPlink)!=-1   ||
-            stdoutBuffer.find(newKeyVsh)!=-1)
+            stdoutBuffer.find(newKeyVsh)!=-1     ||
+            stdoutBuffer.find(newKeySSHComm)!=-1)
         {
 /* new key */
+            bool unix_y_n = (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
+                             stdoutBuffer.find(newKeySSHComm)!=-1);
 
-            n1=stdoutBuffer.find(fingerprintPrompt) + strlen(fingerprintPrompt);
-            n2=stdoutBuffer.find(QRegExp("[^ 0-9a-f:]"), n1+4);
-            fingerprint=stdoutBuffer.mid(n1,n2-n1);
+            fingerprint = findKeyFingerprint(stdoutBuffer);
 
-            QString msg=newKeyMsg.arg(host).arg(fingerprint).arg(host);
+            QString msg = newKeyMsg.arg(host).arg(fingerprint).arg(host);
 
             stopHeartBeat();
 
@@ -176,10 +185,8 @@ void SSHUnx::stateMachine()
             stdoutBuffer="";
             if (res==0)
             {
-                if (ssh.find("vsh.exe")!=-1)
-                    proc->writeToStdin( "y\n" );
-                else
-                    proc->writeToStdin( "yes\n" );
+                if (unix_y_n) proc->writeToStdin( "yes\n" );
+                else          proc->writeToStdin( "y\n" );
                 break;
             } else
             {
