@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SimpleTextEditor.h,v 1.3 2004/06/02 06:40:52 vkurland Exp $
+  $Id: SimpleTextEditor.h,v 1.4 2007/01/06 22:03:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,7 +35,8 @@ class SimpleTextEditor : public SimpleTextEditor_q
 
  public:
 
-    SimpleTextEditor(const QString &txt,
+    SimpleTextEditor(QWidget *parent,
+                     const QString &txt,
                      bool enableLoadFromFile=true,
                      const QString &title="");
 
