@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TCPServiceDialog.cpp,v 1.24 2007/04/14 00:18:43 vkurland Exp $
+  $Id: TCPServiceDialog.cpp,v 1.25 2007/05/08 02:11:39 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,6 +42,7 @@
 #include <qcombobox.h>
 #include <qpushbutton.h>
 #include <qmessagebox.h>
+#include <qlabel.h>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -76,8 +77,12 @@ void TCPServiceDialog::loadFWObject(FWObject *o)
     syn_s->setChecked( s->getBool("syn_flag") );
     fin_s->setChecked( s->getBool("fin_flag") );
 
+    established->setChecked( s->getBool("established") );
+
     comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
+    toggleEstablished();
+
     //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
@@ -134,6 +139,9 @@ void TCPServiceDialog::loadFWObject(FWObject *o)
     fin_s->setEnabled(!o->isReadOnly());
     setDisabledPalette(fin_s);
 
+    established->setEnabled(!o->isReadOnly());
+    setDisabledPalette(established);
+
     comment->setReadOnly(o->isReadOnly());
     setDisabledPalette(comment);
 
@@ -203,7 +211,7 @@ void TCPServiceDialog::applyChanges()
     obj->setInt("src_range_end",   se->value() );
     obj->setInt("dst_range_start", ds->value() );
     obj->setInt("dst_range_end",   de->value() );
-        
+
     obj->setBool("urg_flag_mask", urg_m->isChecked() );
     obj->setBool("ack_flag_mask", ack_m->isChecked() );
     obj->setBool("psh_flag_mask", psh_m->isChecked() );
@@ -218,6 +226,8 @@ void TCPServiceDialog::applyChanges()
     obj->setBool("syn_flag",      syn_s->isChecked() );
     obj->setBool("fin_flag",      fin_s->isChecked() );
 
+    obj->setBool("established",  established->isChecked());
+
     om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     init=true;
@@ -248,3 +258,33 @@ void TCPServiceDialog::closeEvent(QCloseEvent *e)
 
 }
 
+void TCPServiceDialog::toggleEstablished()
+{
+    bool using_established = established->isChecked();
+
+    urg_m->setEnabled( !using_established );
+    ack_m->setEnabled( !using_established );
+    psh_m->setEnabled( !using_established );
+    rst_m->setEnabled( !using_established );
+    syn_m->setEnabled( !using_established );
+    fin_m->setEnabled( !using_established );
+         
+    urg_s->setEnabled( !using_established );
+    ack_s->setEnabled( !using_established );
+    psh_s->setEnabled( !using_established );
+    rst_s->setEnabled( !using_established );
+    syn_s->setEnabled( !using_established );
+    fin_s->setEnabled( !using_established );
+
+    flags_lbl_1->setEnabled( !using_established );
+    flags_lbl_2->setEnabled( !using_established );
+    flags_lbl_3->setEnabled( !using_established );
+    flags_lbl_u->setEnabled( !using_established );
+    flags_lbl_a->setEnabled( !using_established );
+    flags_lbl_p->setEnabled( !using_established );
+    flags_lbl_r->setEnabled( !using_established );
+    flags_lbl_s->setEnabled( !using_established );
+    flags_lbl_f->setEnabled( !using_established );
+
+}
+
