@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: filePropDialog.cpp,v 1.6 2006/08/04 22:15:26 vkurland Exp $
+  $Id: filePropDialog.cpp,v 1.7 2007/05/22 22:59:31 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -105,9 +105,8 @@ void filePropDialog::printRevHistory()
     // 4. send lines to the stream
     //
 	
-    int pageWidth = 0;
-
-    int pageHeight = 0;
+    //int pageWidth = 0;
+    //int pageHeight = 0;
     bool  fullPage = false;
 
     float margin;
@@ -118,10 +117,10 @@ void filePropDialog::printRevHistory()
 #endif
     int   resolution = 150;
     bool  printHeader = true;
-    bool  printLegend = true;
-    bool  printObjects = true;
-    bool  newPageForSection = false;
-    int   tableResolution = 2;   // 50%, 75%, 100%, 150%, 200%, default 100%
+    //bool  printLegend = true;
+    //bool  printObjects = true;
+    //bool  newPageForSection = false;
+    //int   tableResolution = 2;   // 50%, 75%, 100%, 150%, 200%, default 100%
 	
 #if (QT_VERSION > 0x030200)
     printer->setOptionEnabled(QPrinter::PrintPageRange, true);
@@ -155,7 +154,7 @@ void filePropDialog::printRevHistory()
 	    return;
 	}
 
-	QSize margins = printer->margins();
+	//QSize margins = printer->margins();
 
 	pr.beginPage();   // resets yPos
 	QStringList sl;
