@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.cpp,v 1.4 2007/01/06 08:24:57 vkurland Exp $
+  $Id: instBatchOptionsDialog.cpp,v 1.5 2007/05/11 02:14:29 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,7 +40,8 @@
 using namespace std;
 using namespace libfwbuilder;
 
-instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent) : instOptionsDialog(parent)
+instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent, instConf *_cnf) :
+    instOptionsDialog(parent, _cnf)
 {
     dialogTitleLine->setText(QString("<p align=\"center\"><b><font size=\"+2\">")+
                              tr("Batch install options")+
