@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.108 2007/07/13 05:32:55 vkurland Exp $
+  $Id: instDialog.cpp,v 1.109 2007/08/26 03:07:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -717,7 +717,7 @@ bool instDialog::doInstallPage()
  * use current Windows account name to log in to the firewall and this
  * is unlikely to work anyway. This seems to be a decent workaround.
  */
-        if (!cnf.user.isEmpty() && ssh.find("plink.exe")!=-1)
+        if (!cnf.user.isEmpty() && ssh.find(QString("plink.exe"),0,false)!=-1)
         {
             args.push_back("-ssh");
             args.push_back("-pw");
@@ -1002,7 +1002,7 @@ void instDialog::initiateCopy(const QString &file)
 #ifdef _WIN32
     args.push_back(ssh);
 
-    if (!cnf.user.isEmpty() && ssh.find("plink.exe")!=-1)
+    if (!cnf.user.isEmpty() && ssh.find(QString("plink.exe"),0,false)!=-1)
     {
         args.push_back("-ssh");
         args.push_back("-pw");
@@ -1188,7 +1188,7 @@ void instDialog::continueRun()
             args.push_back(ssh);
 
             if (!cnf.user.isEmpty() &&
-                ssh.find("plink.exe")!=-1) args.push_back("-ssh");
+                ssh.find(QString("plink.exe"),0,false)!=-1) args.push_back("-ssh");
 
             args.push_back("-pw");
             args.push_back(cnf.pwd);
