@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.h,v 1.34 2007/01/30 16:48:10 vkurland Exp $
+  $Id: instDialog.h,v 1.35 2007/05/11 02:14:30 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -87,6 +87,7 @@ class instDialog : public instDialog_q {
     
     int         phase;
 
+    QString replaceMacrosInCommand(const QString &cmd);
     QString getActivationCmd();
     //libfwbuilder::Firewall * firewall;
     t_fwSet reqFirewalls;
@@ -173,11 +174,11 @@ class instDialog : public instDialog_q {
     void addReqFirewall(libfwbuilder::Firewall *f);
     void addToLog(const QString &buf); 
     
- protected:
+protected:
 
     virtual void showEvent( QShowEvent *ev);
     virtual void hideEvent( QHideEvent *ev);
-    virtual void prepareInstallerOptions(bool fPix);
+    virtual void prepareInstallerOptions();
     
     virtual void prepareInstConf(libfwbuilder::Firewall *fw);
     virtual void storeInstallerOptions();
