@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: linux24AdvancedDialog.cpp,v 1.2 2004/10/25 04:23:14 vkurland Exp $
+  $Id: linux24AdvancedDialog.cpp,v 1.4 2006/03/16 05:38:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "platforms.h"
 
 #include "linux24AdvancedDialog.h"
+#include "ObjectManipulator.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -156,6 +157,7 @@ void linux24AdvancedDialog::accept()
 
     data.saveAll();
 
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
     linux24AdvancedDialog_q::accept();
 }
 
