@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pixAdvancedDialog.h,v 1.4 2004/11/13 07:31:27 vkurland Exp $
+  $Id: pixAdvancedDialog.h,v 1.5 2006/04/23 22:15:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@ class QWidget;
 class QSpinBox;
 class QComboBox;
 class QCheckBox;
+class QProcess;
 
 namespace libfwbuilder {
     class FWObject;
@@ -72,20 +73,17 @@ class pixAdvancedDialog : public pixAdvancedDialog_q
     DialogData                       data;
     std::list<struct fixupControl>   allFixups;
     bool                             syslogDeviceIdSupported;
+    QProcess                        *fwb_pix_proc;
+    QString                          proc_buffer;
     
  public:
     pixAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
 
     void setDefaultTimeoutValue(const QString &option);
-    void showFixups();
+    void updateFixupCommandsDisplay();
     void loadFixups();
     void saveFixups();
     
-    QString _printFixupCommand(const QString &fixup_name,
-                               int   sw,
-                               int   arg1, 
-                               int   arg2,
-                               bool  ov);
     int translateFixupSwitchFromOptionToWidget(int o);
     int translateFixupSwitchFromWidgetToOption(int o);
     void changeAllFixups(int state);
@@ -105,9 +103,13 @@ protected slots:
     virtual void disableAllFixups();
     virtual void skipAllFixups();
     virtual void scriptACLModeChanged();
+    virtual void displayCommands();
     
 public slots:
-
+     virtual void readFromStdout();
+     virtual void readFromStderr();
+     virtual void fwb_pix_Finished();
+     virtual void allXMLSent();
 };
 
 #endif // __PIXADVANCEDDIALOG_H
