@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp,v 1.36 2007/04/14 01:48:51 vkurland Exp $
+  $Id: platforms.cpp,v 1.43 2007/07/14 22:02:01 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -36,6 +36,7 @@
 #include "fwbuilder/Management.h"
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/Rule.h"
+#include "fwbuilder/Policy.h"
 
 #include <algorithm>
 
@@ -186,9 +187,12 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 {
     bool res=true;
     FWObject *p;
+    PolicyRule *rule = NULL;
 
     p=opt;
-    do {  p=p->getParent();
+    do {
+        p=p->getParent();
+        if (PolicyRule::cast(p)!=NULL) rule = PolicyRule::cast(p);
     } while ( p!=NULL && Firewall::cast(p)==NULL );
 
     assert(p!=NULL);
@@ -220,7 +224,6 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 
                    opt->getInt("ulog_nlgroup")<=1        &&
                    opt->getStr("limit_suffix").empty()   &&
-		   ! opt->getBool("stateless")           &&
                    ! opt->getBool("firewall_is_part_of_any_and_networks"));
 	}
 
@@ -242,29 +245,61 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 
 	if (platform=="pf") 
         {
-	    res= ( opt->getStr("log_prefix").empty()       &&  
-		   ! opt->getBool("stateless")             &&
-                   opt->getInt("pf_rule_max_state")<=0     &&
-                   ! opt->getBool("pf_source_tracking")    &&
-                   opt->getInt("pf_max_src_conn")<=0       &&
-                   opt->getInt("pf_max_src_conn_rate_num")<=0       &&
-                   opt->getInt("pf_max_src_conn_rate_seconds")<=0
-
-            );
+            string vers=p->getStr("version");
+            if (vers=="4.x")
+            {
+                res= ( opt->getStr("log_prefix").empty()       &&  
+                       opt->getInt("pf_rule_max_state")<=0     &&
+                       ! opt->getBool("pf_source_tracking")    &&
+                       opt->getInt("pf_max_src_conn")<=0       &&
+                       opt->getInt("pf_max_src_conn_rate_num")<=0       &&
+                       opt->getInt("pf_max_src_conn_rate_seconds")<=0 &&
+                       ! opt->getBool("pf_keep_state")
+                );
+            }else
+            {
+                res= ( opt->getStr("log_prefix").empty()       &&  
+                       opt->getInt("pf_rule_max_state")<=0     &&
+                       ! opt->getBool("pf_source_tracking")    &&
+                       opt->getInt("pf_max_src_conn")<=0       &&
+                       opt->getInt("pf_max_src_conn_rate_num")<=0       &&
+                       opt->getInt("pf_max_src_conn_rate_seconds")<=0
+                );
+            }
 	}
 
 	if (platform=="ipf") 
         {
 	    res= ( opt->getStr("ipf_log_facility").empty()       && 
                    opt->getStr("log_level").empty()      && 
-		   ! opt->getBool("stateless") &&
 		   ! opt->getBool("ipf_keep_frags") &&
                    ! opt->getBool("ipf_return_icmp_as_dest") );
 	}
 
 	if (platform=="ipfw") 
         {
-	    res= ( ! opt->getBool("stateless") );
+	    //res= ( ! opt->getBool("stateless") );
+            res = true;
+	}
+
+        if (rule!=NULL)
+        {
+            PolicyRule::Action act=rule->getAction();
+            if (act==PolicyRule::Accept || act==PolicyRule::Tag)
+            {
+                // by default, these actions are not stateless
+                res = res && (!opt->getBool("stateless"));
+            } else
+            {
+                // other actions are stateless by default
+                res = res && opt->getBool("stateless");
+            }
+        }
+
+        // all rules are stateless for IOS ACL
+	if (platform=="iosacl")
+        {
+	    res = true; // ignore "stateless" option
 	}
 
     }
@@ -349,7 +384,7 @@ list<QStringPair> getVersionsForPlatform(const QString &platform)
         res.push_back(QStringPair("1.3.0", QObject::tr("1.3.0 or later")));
     } else
     {
-        if (platform=="pix" || platform=="fwsm") 
+        if (platform=="pix" || platform=="fwsm" || platform=="iosacl")
         {
             QString lst=Resources::platform_res[platform.ascii()]->getResourceStr(
                 "/FWBuilderResources/Target/versions").c_str();
@@ -363,6 +398,8 @@ list<QStringPair> getVersionsForPlatform(const QString &platform)
             if (platform=="pf") 
             {
                 res.push_back(QStringPair("","- any -"));
+                res.push_back(QStringPair("3.x", QObject::tr("3.x")));
+                res.push_back(QStringPair("4.x", QObject::tr("4.x")));
 /* add pf versions here */
             } else
             {
@@ -526,3 +563,24 @@ QString getActionNameForPlatform(PolicyRule::Action action,const QString &platfo
     }
     return action_name;
 }
+
+/*
+ * this function provides logic for the decision whether the rule
+ * should be stateless by default. Currently it only depends on the
+ * action, but may depend on the platform as well.
+ *
+ * actions Accept, Tag and Route by default assume the rule is
+ * stateful.  Other actions by default assume it is stateless
+ * and set rule option accordingly
+ *
+ * See bugs #1676635 and 1671910
+ */
+bool getStatelessFlagForAction(PolicyRule *rule)
+{
+    PolicyRule::Action act = rule->getAction();
+    if (act==PolicyRule::Accept ||
+        act==PolicyRule::Tag    ||
+        act==PolicyRule::Route) return false;
+    else
+        return true;
+}
