@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.h,v 1.11 2006/10/24 03:43:25 vkurland Exp $
+  $Id: platforms.h,v 1.12 2007/05/08 05:20:54 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,6 +42,7 @@
 namespace libfwbuilder {
     class FWOptions;
     class Firewall;
+    class PolicyRule;
 };
 
 void init_platforms();
@@ -106,5 +107,7 @@ QString getScreenName(QString s,const QStringList &sl);
 
 QString getActionNameForPlatform(libfwbuilder::PolicyRule::Action action,const QString &platform);
 
+bool getStatelessFlagForAction(libfwbuilder::PolicyRule *rule);
+
 #endif
 
