@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.h,v 1.30 2006/08/26 17:11:28 vkurland Exp $
+  $Id: utils.h,v 1.32 2007/05/23 03:05:51 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -46,23 +46,6 @@ class QListBox;
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/FWReference.h"
 
-struct FWObjectNameCmpPredicate :
-    public std::binary_function<libfwbuilder::FWObject*, libfwbuilder::FWObject*, bool>
-{
-    bool operator()(libfwbuilder::FWObject *a,libfwbuilder::FWObject *b)
-    {
-        return a->getName() < b->getName();
-    }
-};
-
-class findFWObjectIDPredicate: public std::unary_function<libfwbuilder::FWObject*, bool>
-{
-    std::string _id;
-    public:
-    findFWObjectIDPredicate(const std::string &id):_id(id) {}
-    bool operator()(const libfwbuilder::FWObject *o) const {return o->getId()==_id;}
-};
-
 typedef std::pair<const QString,QString> QStringPair;
 
 // a predicate used to compare first string in pair<QString,QString>
@@ -71,14 +54,16 @@ class findFirstInQStringPair {
     QString str;
     public:
     findFirstInQStringPair(const QString &d) { str=d; }
-    bool operator()(std::pair<const QString,QString> &_d) { return (str == _d.first); }
+    bool operator()(std::pair<const QString,QString> &_d)
+    { return (str == _d.first); }
 };
 
 class findSecondInQStringPair {
     QString str;
     public:
     findSecondInQStringPair(const QString &d) { str=d; }
-    bool operator()(std::pair<const QString,QString> &_d) { return (str == _d.second); }
+    bool operator()(std::pair<const QString,QString> &_d)
+    { return (str == _d.second); }
 };
 
 
@@ -90,8 +75,10 @@ extern int addPopupMenuItem(QObject *res,
                             const char* member,
                             const QKeySequence &accel = 0);
 
-extern void fillLibraries(QComboBox *libs, libfwbuilder::FWObject *obj, bool rw=false);
-extern void fillLibraries(QListBox *libs, libfwbuilder::FWObject *obj, bool rw=false);
+extern void fillLibraries(QComboBox *libs, libfwbuilder::FWObject *obj,
+                          bool rw=false);
+extern void fillLibraries(QListBox *libs, libfwbuilder::FWObject *obj,
+                          bool rw=false);
 
 
 /**
@@ -136,23 +123,10 @@ extern QString readHostOS(QComboBox *hostOS);
 extern void setPlatform(QComboBox *platform,const QString &pl);
 extern void setHostOS(QComboBox *hostOS,const QString &os);
 
-extern void findFirewalls(libfwbuilder::FWObject *o,
-                          std::list<libfwbuilder::FWObject*> &fwlist,
-                          bool skip_system_libs=true);
-
-extern void findHosts(libfwbuilder::FWObject *o,
-                      std::list<libfwbuilder::FWObject*> &fwlist,
-                      bool skip_system_libs=true);
-
-extern void findByObjectType(libfwbuilder::FWObject *o,
-                             const std::string &otype,
-                             std::list<libfwbuilder::FWObject*> &fwlist,
-                             bool skip_system_libs=true);
-
 extern void setDisabledPalette(QWidget *w);
 
 extern QString getAddrByName(const QString &name);
 extern QString getNameByAddr(const QString &addr);
 extern QString wordWrap(const QString& ,int);
-extern libfwbuilder::FWReference* findRef(libfwbuilder::FWObject *o,libfwbuilder::FWObject *p);
+
 #endif
