@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp,v 1.25 2006/09/11 00:41:09 vkurland Exp $
+  $Id: NATCompiler_ipt.cpp,v 1.26 2007/01/15 01:21:58 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -94,8 +94,12 @@ string NATCompiler_ipt::getAddressTableVarName(FWObject *at)
     ostringstream  ostr;
     string name=at->getName();
     string::size_type p1;
-    while ( (p1=name.find(" "))!=string::npos)
-        name=name.replace(p1,1,"_");
+    char *bad_shell_chars = " !#$&*()-+=\\|{}[]?<>,.";
+    for (char *cptr=bad_shell_chars; *cptr; cptr++)
+    {
+        while ( (p1=name.find(*cptr))!=string::npos)
+            name=name.replace(p1,1,"_");
+    }
     ostr << "at_" << name;
     return ostr.str();
 }
