@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.39 2007/04/14 00:57:27 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp,v 1.42 2007/06/17 03:28:20 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -448,7 +448,11 @@ void  OSConfigurator_linux24::printShellFunctions()
     output << "    set $L"                                 << endl;
     output << "    type=$4"                                << endl;
     output << "    IFS=$OIFS"                              << endl;
+    output << "    if test \"$type\" = \"NO-CARRIER\"; then" << endl;
+    output << "      type=$5"                              << endl;
+    output << "    fi"                                     << endl;
     output << ""                                           << endl;
+
 /*
  *  see comment about using grep with or without regex below
  */
@@ -613,12 +617,13 @@ void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
 /* there is no need to load modules on linksys */
     if (options->getBool("load_modules") && !nomod)
     {
+        std::string sed_command = "sed  -e 's/^.*\\///' -e 's/\\([^\\.]\\)\\..*/\\1/'";
 	output << endl;
         output << "MODULES_DIR=\"/lib/modules/`uname -r`/kernel/net/\"" << endl;
-        output << "MODULES=`find $MODULES_DIR -name '*conntrack*'  |  sed -e 's/\\.[^\\.]*$//' -e 's/^.*\\///'`" << endl;
+        output << "MODULES=`find $MODULES_DIR -name '*conntrack*'|" << sed_command <<  "`" << endl;
         if (have_nat)
         {
-            output << "MODULES=\"$MODULES `find $MODULES_DIR -name '*nat*'  |  sed -e 's/\\.[^\\.]*$//' -e 's/^.*\\///'`\"" << endl;
+            output << "MODULES=\"$MODULES `find $MODULES_DIR -name '*nat*'|" << sed_command <<  "`\"" << endl;
 
         }
 
