@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp,v 1.36 2007/04/24 05:59:55 vkurland Exp $
+  $Id: PolicyCompiler_PrintRule.cpp,v 1.42 2007/07/19 01:46:30 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -349,7 +349,7 @@ string PolicyCompiler_ipt::PrintRule::_printDirectionAndInterface(PolicyRule *ru
     Interface *rule_iface =
         compiler->getCachedFwInterface(rule->getInterfaceId());
 
-    if (rule_iface->isBridgePort() && version == "1.3.0")
+    if (rule_iface && rule_iface->isBridgePort() && version == "1.3.0")
     {
         if (rule->getDirection()==PolicyRule::Inbound)   
             ostr << " -m physdev --physdev-in "  << iface_name; 
@@ -415,7 +415,7 @@ string PolicyCompiler_ipt::PrintRule::_printGlobalLogParameters()
     return _printLogParameters(NULL);
 }
 
-string PolicyCompiler_ipt::PrintRule::_printLogPrefix(int rule_num,
+string PolicyCompiler_ipt::PrintRule::_printLogPrefix(const string &rule_num,
 						      const string &action,
 						      const string &interf,
 						      const string &chain,
@@ -425,7 +425,7 @@ string PolicyCompiler_ipt::PrintRule::_printLogPrefix(int rule_num,
     string s=prefix;
 
 /* deal with our logging macros:
- * %N - rule number
+ * %N - rule number  ('2', or '2/3' for rule in a branch)
  * %A - action
  * %I - interface name
  * %C - chain name
@@ -433,9 +433,7 @@ string PolicyCompiler_ipt::PrintRule::_printLogPrefix(int rule_num,
     string::size_type n;
     if ((n=s.find("%N"))!=string::npos ) 
     {
-      std::ostringstream s1;
-      s1 << rule_num;
-      s.replace(n,2,s1.str());
+      s.replace(n,2,rule_num);
     }
     if ((n=s.find("%A"))!=string::npos ) 
     {
@@ -469,7 +467,16 @@ string PolicyCompiler_ipt::PrintRule::_printLogPrefix(PolicyRule *rule,
   string rule_iface =  rule->getInterfaceStr();
   if (rule_iface=="")  rule_iface = "global";
 
-  return _printLogPrefix(rule->getPosition(),
+  std::ostringstream s1;
+  int pos=rule->getPosition();
+  // parent_rule_num is set by processor "Branching" for branch rules
+  string ppos = rule->getStr("parent_rule_num");
+
+  if (ppos != "")
+      s1 << ppos << "/";
+  s1 << pos;
+
+  return _printLogPrefix(s1.str(),
 			 action,
 			 rule_iface,
 			 rule->getStr("ipt_chain"),
@@ -1090,7 +1097,6 @@ bool  PolicyCompiler_ipt::PrintRule::processNext()
 
 string PolicyCompiler_ipt::PrintRule::PolicyRuleToString(PolicyRule *rule)
 {
-
     FWOptions *ruleopt =rule->getOptionsObject();
     FWObject    *ref;
 
@@ -1162,18 +1168,13 @@ string PolicyCompiler_ipt::PrintRule::PolicyRuleToString(PolicyRule *rule)
 /* keeping state does not apply to deny/reject 
    however some rules need state check even if action is Deny
 
-    if ( ! ruleopt->getBool("stateless") && rule->getAction()==PolicyRule::Accept) 
-    {
-	command_line << " -m state --state NEW ";
-    }
 
-    if (rule->getBool("force_state_check"))
-	command_line << " -m state --state NEW ";
+   autoupgrade transformation 2.1.11 -> 2.1.12 adds rule option
+   'stateless=True' for rules with action NOT 'Accept', 'Tag' or
+   'Route'. No need to check action here, just rely on this option
+   and internal flag 'force_state_check'  (05/07/07 --vk)
 */
-
-    if ((!ruleopt->getBool("stateless") && 
-         (rule->getStr("stored_action")=="Accept" || rule->getStr("stored_action")=="Tag")) ||
-         rule->getBool("force_state_check") )
+    if (!ruleopt->getBool("stateless") || rule->getBool("force_state_check") )
     {
         /*
          * But not, when the line already contains a state matching
@@ -1201,7 +1202,8 @@ string PolicyCompiler_ipt::PrintRule::_declareTable()
 
 string PolicyCompiler_ipt::PrintRule::_flushAndSetDefaultPolicy()
 {
-    PolicyCompiler_ipt *ipt_comp=dynamic_cast<PolicyCompiler_ipt*>(compiler);
+    PolicyCompiler_ipt *ipt_comp = dynamic_cast<PolicyCompiler_ipt*>(compiler);
+    FWOptions *fwopt = compiler->getCachedFwOpt();
     ostringstream res;
 
 //    if (ipt_comp->my_table=="filter")
@@ -1210,18 +1212,22 @@ string PolicyCompiler_ipt::PrintRule::_flushAndSetDefaultPolicy()
         res << "$IPTABLES -P INPUT   DROP" << endl;
         res << "$IPTABLES -P FORWARD DROP" << endl;
 
-        /*
-         * test if ip6tables is installed and if it works. It may be installed
-         * on the system but fail because ipv6 is not compiled into the
-         * kernel.
-         */
-        res << "ip6tables -L -n > /dev/null 2>&1 && {"    << endl; 
-        res << "  ip6tables -P OUTPUT  DROP" << endl;
-        res << "  ip6tables -P INPUT   DROP" << endl;
-        res << "  ip6tables -P FORWARD DROP" << endl;
-        res << "}"                         << endl;
-        res << endl;
-
+        if ( ! fwopt->getBool("no_ipv6_default_policy") )
+        {
+            /*
+             * test if ip6tables is installed and if it works. It may be installed
+             * on the system but fail because ipv6 is not compiled into the
+             * kernel.
+             */
+            res << "ip6tables -L -n > /dev/null 2>&1 && {"    << endl; 
+            res << "  ip6tables -P OUTPUT  DROP" << endl;
+            res << "  ip6tables -P INPUT   DROP" << endl;
+            res << "  ip6tables -P FORWARD DROP" << endl;
+            res << "  ip6tables -A INPUT  -i lo  -j ACCEPT " << endl;
+            res << "  ip6tables -A OUTPUT  -o lo  -j ACCEPT " << endl;
+            res << "}"                         << endl;
+            res << endl;
+        }
 /*
  * need to flush all tables and chains before setting up any rules
  */
@@ -1387,7 +1393,8 @@ string PolicyCompiler_ipt::PrintRule::_printOptionalGlobalRules()
 
             res << _startRuleLine()
                 << "drop_invalid  -j LOG  --log-level debug --log-prefix "
-		<< _printLogPrefix(-1,"DENY","global","drop_invalid","BLOCK INVALID",s)
+		<< _printLogPrefix("-1",
+                                   "DENY","global","drop_invalid","BLOCK INVALID",s)
                 << _endRuleLine();
 
             res << _startRuleLine()
