@@ -90,6 +90,9 @@ public:
 	public: void mROUTE_TEE(bool _createToken);
 	public: void mLOG_PREFIX(bool _createToken);
 	public: void mLOG_LEVEL(bool _createToken);
+	public: void mLOG_TCP_SEQ(bool _createToken);
+	public: void mLOG_TCP_OPT(bool _createToken);
+	public: void mLOG_IP_OPT(bool _createToken);
 	public: void mULOG_PREFIX(bool _createToken);
 	public: void mULOG_QTHR(bool _createToken);
 	public: void mULOG_NLG(bool _createToken);
