@@ -38,7 +38,7 @@ class CUSTOM_API IPTCfgParser : public ANTLR_USE_NAMESPACE(antlr)LLkParser, publ
 
     public:
     
-    std::ostringstream dbg;
+    std::ostream *dbg;
     IPTImporter *importer;
 #line 37 "IPTCfgParser.hpp"
 public:
@@ -123,10 +123,10 @@ protected:
 private:
 	static const char* tokenNames[];
 #ifndef NO_STATIC_CONSTS
-	static const int NUM_TOKENS = 116;
+	static const int NUM_TOKENS = 119;
 #else
 	enum {
-		NUM_TOKENS = 116
+		NUM_TOKENS = 119
 	};
 #endif
 	
