@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: pf.cpp,v 1.37 2006/10/19 04:20:13 vkurland Exp $
+  $Id: pf.cpp,v 1.40 2007/07/14 21:20:38 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@
 #include <algorithm>
 #include <functional>
 #include <stdexcept>
+#include <utility>
 
 #ifndef _WIN32
 #  include <unistd.h>
@@ -111,7 +112,24 @@ class UpgradePredicate: public XMLTools::UpgradePredicate
 	return false;
     }
 };
+
+// a functor to join list<string> into a string with separator sep
+class join : public std::unary_function<std::string, void>
+{
+    std::string *result;
+    std::string  separator;
+public:
+    join(std::string *res, const std::string &s)
+    { result = res; separator = s; }
+    void operator()(std::string &s);
+};
     
+void join::operator()(std::string &s)
+{
+    if (!result->empty()) *result += separator;
+    *result += s;
+}
+
 void usage(const char *name)
 {
     cout << _("Firewall Builder:  policy compiler for OpenBSD PF") << endl;
@@ -280,8 +298,9 @@ int main(int argc, char * const *argv)
 	Firewall*  fw=objdb->findFirewallByName(fwobjectname);
 
         /* some initial sanity checks */
-        list<FWObject*> l2=fw->getByType(Interface::TYPENAME);
-        for (list<FWObject*>::iterator i=l2.begin(); i!=l2.end(); ++i) 
+        list<FWObject*> all_interfaces=fw->getByType(Interface::TYPENAME);
+        for (list<FWObject*>::iterator i=all_interfaces.begin();
+             i!=all_interfaces.end(); ++i) 
         {
             Interface *iface=dynamic_cast<Interface*>(*i);
             assert(iface);
@@ -463,30 +482,43 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 
         pf_file << endl;
 
-        bool f1=(options->getBool("pf_do_limit_frags") &&
-                 options->getInt("pf_limit_frags")>0 );
-        bool f2=(options->getBool("pf_do_limit_states") &&
-                 options->getInt("pf_limit_states")>0 );
+        list<string> limits;
+        if (options->getBool("pf_do_limit_frags") &&
+            options->getInt("pf_limit_frags")>0 )
+            limits.push_back(string("frags ") +
+                             options->getStr("pf_limit_frags"));
 
-        if ( f1 || f2 )
+        if (options->getBool("pf_do_limit_states") &&
+            options->getInt("pf_limit_states")>0 )
+            limits.push_back(string("states ") +
+                             options->getStr("pf_limit_states"));
+
+        if (options->getBool("pf_do_limit_src_nodes") &&
+            options->getInt("pf_limit_src_nodes")>0 )
+            limits.push_back(string("src-nodes ") +
+                             options->getStr("pf_limit_src_nodes"));
+
+        if (options->getBool("pf_do_limit_tables") &&
+            options->getInt("pf_limit_tables")>0 )
+            limits.push_back(string("tables ") +
+                             options->getStr("pf_limit_tables"));
+
+        if (options->getBool("pf_do_limit_table_entries") &&
+            options->getInt("pf_limit_table_entries")>0 )
+            limits.push_back(string("table-entries ") +
+                             options->getStr("pf_limit_table_entries"));
+
+        if (limits.size() > 0)
         {
-            pf_file << "set limit { ";
-
-            bool first=true;
-            if (f1)
-            {
-                pf_file << "frags " << options->getInt("pf_limit_frags");
-                first=false;
-            }
-            if (f2)
-            {
-                if (!first) pf_file << ", ";
-                pf_file << "states " << options->getInt("pf_limit_states");
-            }
-            pf_file << " }" << endl;
+            pf_file << "set limit ";
+            if (limits.size() > 1 ) pf_file << "{ ";
+            string all_limits;
+            for_each(limits.begin(), limits.end(), join( &all_limits, ", "));
+            pf_file << all_limits;
+            if (limits.size() > 1 ) pf_file << " }";
+            pf_file << endl;
         }
 
-
         pf_file << printTimeout(options,
                                 "pf_do_timeout_interval","pf_timeout_interval",
                                 "interval");
@@ -550,6 +582,22 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             pf_file << "set optimization "
                     << options->getStr("pf_optimization") << endl;
 
+        // check if any interface is marked as 'unprotected'
+        // and generate 'set skip on <ifspec>' commands
+
+        if (fw->getStr("version")=="4.x") 
+        {
+            for (list<FWObject*>::iterator i=all_interfaces.begin();
+                 i!=all_interfaces.end(); ++i) 
+            {
+                Interface *iface=dynamic_cast<Interface*>(*i);
+                assert(iface);
+
+                if ( iface->isUnprotected())  
+                    pf_file << "set skip on " << iface->getName() << endl;
+            }
+        }
+
         pf_file << endl;
 
         if (prolog_place == "pf_file_after_set")
@@ -759,16 +807,22 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	fw_file << endl;
 
         fw_file << "$PFCTL " << pfctl_dbg << pfctl_f_option
-                << "${FWDIR}/" << pf_file_name << endl;
+                << "${FWDIR}/" << pf_file_name
+                << " || exit 1"
+                << endl;
 
         for (map<string,string>::iterator i=anchor_files.begin();
              i!=anchor_files.end(); ++i)
             fw_file << "$PFCTL " << pfctl_dbg
                     << "-a " << i->first << " "
                     << pfctl_f_option
-                    << "${FWDIR}/" << i->second << endl;
+                    << "${FWDIR}/" << i->second
+                    << " || exit 1"
+                    << endl;
 
-	fw_file << "$PFCTL -e" << endl;
+	fw_file << "$PFCTL -e"
+                << " || exit 1"
+                << endl;
         
         fw_file << endl;
         fw_file << "#" << endl;
