@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.cpp,v 1.9 2006/05/17 02:30:18 vkurland Exp $
+  $Id: NATCompiler_ipf.cpp,v 1.11 2006/09/11 00:41:09 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -152,8 +152,9 @@ bool NATCompiler_ipf::ExpandPortRange::processNext()
       if (numPorts > 20)
       {
 	ostringstream ostr;
-	ostr << string("Expanding port range ") << osrv->getName()
-	     << " yields " << numPorts << " rules";
+	ostr << string("Rule ") << rule->getLabel() << " : "
+             << string("Expanding port range ") << osrv->getName()
+	     << " creates " << numPorts << " rules";
 	compiler->warning(ostr.str());
       }
 
@@ -163,14 +164,15 @@ bool NATCompiler_ipf::ExpandPortRange::processNext()
       for (int p=rs; p<=re; ++p)
       {
 	  NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                compiler->dbcopy->create(NATRule::TYPENAME) );
 	  r->duplicate(rule);
 
-	  FWObject *newSrv = compiler->dbcopy->create(newSrvType,false);
+	  FWObject *newSrv = compiler->dbcopy->create(newSrvType);
 	  newSrv->duplicate(osrv,true);
 	  newSrv->setInt("dst_range_start",p);
 	  newSrv->setInt("dst_range_end",p);
 	  compiler->dbcopy->add(newSrv,false);
+	  compiler->dbcopy->addToIndex(newSrv);
 	  compiler->cacheObj(newSrv);
 
 	  RuleElementOSrv *nosrv = r->getOSrv();
@@ -250,7 +252,7 @@ bool NATCompiler_ipf::AssignInterface::processNext()
                  iface->isBridgePort() || 
                  iface->isLoopback()) continue;
 
-            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) 
+            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) 
 );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
@@ -289,7 +291,7 @@ bool NATCompiler_ipf::AssignInterface::processNext()
                 iface->isBridgePort()) continue;
 
             NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                compiler->dbcopy->create(NATRule::TYPENAME) );
             r->duplicate(rule);
             compiler->temp_ruleset->add(r);
 
@@ -331,7 +333,7 @@ bool NATCompiler_ipf::prepareForLB::processNext()
                 cl.push_back(o);
                 if (cl.size()==2)
                 {
-                    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+                    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
                     compiler->temp_ruleset->add(r);
                     r->duplicate(rule);
                     RuleElementTDst *notdst=r->getTDst();
@@ -345,7 +347,7 @@ bool NATCompiler_ipf::prepareForLB::processNext()
 
             if (cl.size()!=0)
             {
-                NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+                NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
                 compiler->temp_ruleset->add(r);
                 r->duplicate(rule);
                 RuleElementTDst *notdst=r->getTDst();
@@ -473,7 +475,7 @@ bool NATCompiler_ipf::expandAnyService::processNext()
     if (rule->getRuleType()==NATRule::SNAT && srv->isAny())
     {
 	NATRule *r= NATRule::cast(
-	    compiler->dbcopy->create(NATRule::TYPENAME,false) );
+	    compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         r->setBool("needs_portmap",true);
