@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.h,v 1.2 2005/03/29 08:38:33 vkurland Exp $
+  $Id: NATCompiler_ipf.h,v 1.6 2006/05/16 23:00:17 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -36,6 +36,8 @@
 #define H323_PORT   1720
 #define RAUDIO_PORT 5050
 #define ISAKMP_PORT 500
+#define PPTP_PORT   1723
+#define IRC_PORT    6667
 
 namespace fwcompiler {
 
@@ -125,6 +127,34 @@ namespace fwcompiler {
                 eliminateDuplicatesInRE(n,libfwbuilder::RuleElementOSrv::TYPENAME) {}
         };
 
+        /**
+         * Placeholder for MultiAddressRunTime objects that are not
+         * supported for ipf
+         */
+        class processMultiAddressObjectsInRE : public NATRuleProcessor
+        {
+            std::string re_type;
+            public:
+            processMultiAddressObjectsInRE(const std::string &name,
+                      const std::string &t) : NATRuleProcessor(name) { re_type=t; }
+            virtual bool processNext();
+        };
+
+
+        class processMultiAddressObjectsInOSrc : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInOSrc(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementOSrc::TYPENAME) {}
+        };
+
+        class processMultiAddressObjectsInODst : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInODst(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementODst::TYPENAME) {}
+        };
+
 
 	/**
 	 *  prints single policy rule, assuming all groups have been
