@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.cpp,v 1.17 2006/09/15 05:48:22 vkurland Exp $
+  $Id: NATCompiler_pf.cpp,v 1.18 2007/06/21 03:25:45 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -928,14 +928,24 @@ void NATCompiler_pf::compile()
         add( new eliminateDuplicatesInODST(  "eliminate duplicates in ODST") );
         add( new eliminateDuplicatesInOSRV(  "eliminate duplicates in OSRV") );
 
-        add( new swapMultiAddressObjectsInOSrc(" swap MultiAddress -> MultiAddressRunTime in OSrc") );
-        add( new swapMultiAddressObjectsInODst(" swap MultiAddress -> MultiAddressRunTime in ODst") );
+        add( new swapMultiAddressObjectsInOSrc(
+                 " swap MultiAddress -> MultiAddressRunTime in OSrc") );
+        add( new swapMultiAddressObjectsInODst(
+                 " swap MultiAddress -> MultiAddressRunTime in ODst") );
 
-        add( new swapAddressTableObjectsInOSrc("AddressTable -> MultiAddressRunTime in OSrc") );
-        add( new swapAddressTableObjectsInODst("AddressTable -> MultiAddressRunTime in ODst") );
+        add( new swapAddressTableObjectsInOSrc(
+                 "AddressTable -> MultiAddressRunTime in OSrc") );
+        add( new swapAddressTableObjectsInODst(
+                 "AddressTable -> MultiAddressRunTime in ODst") );
+        add( new swapAddressTableObjectsInTDst(
+                 "AddressTable -> MultiAddressRunTime in TDst") );
 
-        add( new processMultiAddressObjectsInOSrc("process MultiAddress objects in OSrc") );
-        add( new processMultiAddressObjectsInODst("process MultiAddress objects in ODst") );
+        add( new processMultiAddressObjectsInOSrc(
+                 "process MultiAddress objects in OSrc") );
+        add( new processMultiAddressObjectsInODst(
+                 "process MultiAddress objects in ODst") );
+        add( new processMultiAddressObjectsInTDst(
+                 "process MultiAddress objects in TDst") );
 
         add( new splitOnOSrv( "split rule on original service" ) );
         add( new fillTranslatedSrv( "fill translated service" ) );
@@ -948,21 +958,26 @@ void NATCompiler_pf::compile()
         add( new splitSDNATRule("split SDNAT rules"      ) );
         add( new NATRuleType( "determine NAT rule types" ) );
         add( new VerifyRules( "verify NAT rules" ) );
-        //add( new splitODstForSNAT("split rule if objects in ODst belong to different subnets"    ) );
-        add( new ReplaceFirewallObjectsODst( "replace references to the firewall in ODst" ) );
-        add( new ReplaceFirewallObjectsTSrc( "replace references to the firewall in TSrc" ) );
+        //add( new splitODstForSNAT(
+        //       "split rule if objects in ODst belong to different subnets"));
+        add( new ReplaceFirewallObjectsODst(
+                 "replace references to the firewall in ODst" ) );
+        add( new ReplaceFirewallObjectsTSrc(
+                 "replace references to the firewall in TSrc" ) );
         add( new ReplaceObjectsTDst( "replace objects in TDst" ) );
 
 	if ( manage_virtual_addr ) {
-            add( new addVirtualAddress( "add virtual addresses for NAT rules" ) );
+            add( new addVirtualAddress("add virtual addresses for NAT rules"));
 	}
 
         add( new ExpandMultipleAddresses( "expand multiple addresses" ) );
         add( new checkForUnnumbered("check for unnumbered interfaces" ) );
-        add( new checkForDynamicInterfacesOfOtherObjects( "check for dynamic interfaces of other hosts and firewalls" ) );
+        add( new checkForDynamicInterfacesOfOtherObjects(
+                 "check for dynamic interfaces of other hosts and firewalls"));
         add( new ExpandAddressRanges( "expand address range objects" ) );
         //add( new ConvertToAtomicForTSrc( "convert to atomic rules" ) );
-        add( new splitForTSrc("split if addresses in TSrc belong to different networks" ) );
+        add( new splitForTSrc(
+                 "split if addresses in TSrc belong to different networks" ));
         add( new AssignInterface( "assign rules to interfaces" ) );
         add( new convertInterfaceIdToStr("prepare interface assignments") );
 
