@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_freebsd.cpp,v 1.3 2005/04/07 15:44:18 vkurland Exp $
+  $Id: OSConfigurator_freebsd.cpp,v 1.4 2006/03/06 03:02:58 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -263,8 +263,7 @@ void  OSConfigurator_freebsd::configureInterfaces()
             Interface *iface=dynamic_cast<Interface*>(*i);
             assert(iface);
 
-            if (iface->isDyn()) continue;
-            if (iface->isUnnumbered()) continue;
+            if (!iface->isRegular()) continue;
 
             FWObjectTypedChildIterator j=iface->findByType(IPv4::TYPENAME);
             for ( ; j!=j.end(); ++j ) 
