@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp,v 1.25 2006/09/09 05:05:02 vkurland Exp $
+  $Id: PolicyCompiler_pf.cpp,v 1.28 2007/06/21 03:25:45 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -457,6 +457,7 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
     if ( getCachedFwOpt()->getBool("pass_all_out") )
     {
 	PolicyRule *r;
+        FWOptions *ruleopt;
 
 	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
 	temp_ruleset->add(r);
@@ -468,6 +469,8 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
         r->setHidden(true);
         r->setFallback(true);
         r->setLabel("fallback rule");
+        ruleopt = r->getOptionsObject();
+        ruleopt->setBool("stateless", true);
 	combined_ruleset->push_back(r);
 
 	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
@@ -480,10 +483,14 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
         r->setHidden(true);
         r->setFallback(true);
         r->setLabel("fallback rule");
+        ruleopt = r->getOptionsObject();
+        ruleopt->setBool("stateless", true);
 	combined_ruleset->push_back(r);
     } else
     {
 	PolicyRule *r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
+        FWOptions *ruleopt;
+
 	temp_ruleset->add(r);
 	r->setAction(PolicyRule::Deny);
 	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
@@ -493,6 +500,8 @@ void PolicyCompiler_pf::addDefaultPolicyRule()
         r->setHidden(true);
         r->setFallback(true);
         r->setLabel("fallback rule");
+        ruleopt = r->getOptionsObject();
+        ruleopt->setBool("stateless", true);
 	combined_ruleset->push_back(r);
     }
 }
@@ -944,15 +953,16 @@ void PolicyCompiler_pf::compile()
 
         if ( fw->getOptionsObject()->getBool ("check_shading") ) 
         {
-            add( new Begin                       ("Detecting rule shadowing" ) );
+            add( new Begin                       ("Detecting rule shadowing" ));
             add( new printTotalNumberOfRules     () );
 
             add( new ItfNegation(            "process negation in Itf"  ) );
-            add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+            add( new InterfacePolicyRules(
+                     "process interface policy rules and store interface ids"));
 
-            add( new recursiveGroupsInSrc( "check for recursive groups in SRC") );
-            add( new recursiveGroupsInDst( "check for recursive groups in DST") );
-            add( new recursiveGroupsInSrv( "check for recursive groups in SRV") );
+            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+            add( new recursiveGroupsInDst("check for recursive groups in DST"));
+            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
             check_for_recursive_groups=false;
 
             add( new ExpandGroups                ("expand groups"          ) );
@@ -960,14 +970,20 @@ void PolicyCompiler_pf::compile()
             add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
             add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
 
-            add( new swapAddressTableObjectsInSrc("AddressTable -> MultiAddressRunTime in Src") );
-            add( new swapAddressTableObjectsInDst("AddressTable -> MultiAddressRunTime in Dst") );
+            add( new swapAddressTableObjectsInSrc(
+                     "AddressTable -> MultiAddressRunTime in Src") );
+            add( new swapAddressTableObjectsInDst(
+                     "AddressTable -> MultiAddressRunTime in Dst") );
 
-            add( new swapMultiAddressObjectsInSrc("MultiAddress -> MultiAddressRunTime in Src") );
-            add( new swapMultiAddressObjectsInDst("MultiAddress -> MultiAddressRunTime in Dst") );
+            add( new swapMultiAddressObjectsInSrc(
+                     "MultiAddress -> MultiAddressRunTime in Src") );
+            add( new swapMultiAddressObjectsInDst(
+                     "MultiAddress -> MultiAddressRunTime in Dst") );
 
-            add( new ExpandMultipleAddressesInSRC("expand objects with multiple addresses in SRC" ) );
-            add( new ExpandMultipleAddressesInDST("expand objects with multiple addresses in DST" ) );
+            add( new ExpandMultipleAddressesInSRC(
+                     "expand objects with multiple addresses in SRC" ) );
+            add( new ExpandMultipleAddressesInDST(
+                     "expand objects with multiple addresses in DST" ) );
             add( new ConvertToAtomic             ("convert to atomic rules") );
             add( new DetectShadowing             ("Detect shadowing"       ) );
             add( new simplePrintProgress         (                         ) );
@@ -979,65 +995,79 @@ void PolicyCompiler_pf::compile()
         add( new Begin() );
         add( new printTotalNumberOfRules() );
 
-//        add( new printScrubRule            (" Defragmentation"             ) );
+//        add( new printScrubRule            (" Defragmentation"             ));
         if (check_for_recursive_groups)
         {
-            add( new recursiveGroupsInSrc("check for recursive groups in SRC") );
-            add( new recursiveGroupsInDst("check for recursive groups in DST") );
-            add( new recursiveGroupsInSrv("check for recursive groups in SRV") );
+            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+            add( new recursiveGroupsInDst("check for recursive groups in DST"));
+            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
         }
 
-        add( new emptyGroupsInSrc(           "check for empty groups in SRC" ) );
-        add( new emptyGroupsInDst(           "check for empty groups in DST" ) );
-        add( new emptyGroupsInSrv(           "check for empty groups in SRV" ) );
+        add( new emptyGroupsInSrc(           "check for empty groups in SRC" ));
+        add( new emptyGroupsInDst(           "check for empty groups in DST" ));
+        add( new emptyGroupsInSrv(           "check for empty groups in SRV" ));
 
-//        add( new doSrcNegation(         "process negation in Src"          ) );
-//        add( new doDstNegation(         "process negation in Dst"          ) );
-	add( new doSrvNegation(         "process negation in Srv"            ) );
+//        add( new doSrcNegation(         "process negation in Src"          ));
+//        add( new doDstNegation(         "process negation in Dst"          ));
+	add( new doSrvNegation(         "process negation in Srv"            ));
 
 // ExpandGroups opens groups, as well as groups in groups etc.
-        add( new ExpandGroups(          "expand groups"                      ) );
+        add( new ExpandGroups(          "expand groups"                      ));
 
-        add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"      ) );
-        add( new eliminateDuplicatesInDST("eliminate duplicates in DST"      ) );
-        add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"      ) );
+        add( new CheckForTCPEstablished(
+                 "check for TCPService objects with flag \"established\"") );
+            
+        add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"      ));
+        add( new eliminateDuplicatesInDST("eliminate duplicates in DST"      ));
+        add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"      ));
 
-        add( new swapAddressTableObjectsInSrc("AddressTable -> MultiAddressRunTime in Src") );
-        add( new swapAddressTableObjectsInDst("AddressTable -> MultiAddressRunTime in Dst") );
+        add( new swapAddressTableObjectsInSrc(
+                 "AddressTable -> MultiAddressRunTime in Src") );
+        add( new swapAddressTableObjectsInDst(
+                 "AddressTable -> MultiAddressRunTime in Dst") );
 
-        add( new swapMultiAddressObjectsInSrc("MultiAddress -> MultiAddressRunTime in Src") );
-        add( new swapMultiAddressObjectsInDst("MultiAddress -> MultiAddressRunTime in Dst") );
+        add( new swapMultiAddressObjectsInSrc(
+                 "MultiAddress -> MultiAddressRunTime in Src") );
+        add( new swapMultiAddressObjectsInDst(
+                 "MultiAddress -> MultiAddressRunTime in Dst") );
 
-        add( new processMultiAddressObjectsInSrc("process MultiAddress objects in Src") );
-        add( new processMultiAddressObjectsInDst("process MultiAddress objects in Dst") );
+        add( new processMultiAddressObjectsInSrc(
+                 "process MultiAddress objects in Src") );
+        add( new processMultiAddressObjectsInDst(
+                 "process MultiAddress objects in Dst") );
 
         add( new ItfNegation(         "process negation in Itf"  ) );
-        add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+        add( new InterfacePolicyRules(
+                 "process interface policy rules and store interface ids") );
 
-	add( new splitIfFirewallInSrc(  "split rule if firewall is in Src"   ) );
-	add( new splitIfFirewallInDst(  "split rule if firewall is in Dst"   ) );
-	add( new fillDirection(         "determine directions"               ) );
-	add( new SplitDirection(        "split rules with direction 'both'"  ) );
-        add( new addLoopbackForRedirect("add loopback to rules that permit redirected services" ) );
-	add( new ExpandMultipleAddresses( "expand objects with multiple addresses" ) );
-        add( new checkForDynamicInterfacesOfOtherObjects( "check for dynamic interfaces of other hosts and firewalls" ) );
-        add( new MACFiltering(          "verify for MAC address filtering"    ) );
-        add( new checkForUnnumbered(    "check for unnumbered interfaces"     ) );
-	add( new addressRanges(         "expand address range objects"        ) );
-	add( new splitServices(         "split rules with different protocols") );
-	add( new separateTCPWithFlags(  "separate TCP services with flags"    ) );
+	add( new splitIfFirewallInSrc(  "split rule if firewall is in Src"   ));
+	add( new splitIfFirewallInDst(  "split rule if firewall is in Dst"   ));
+	add( new fillDirection(         "determine directions"               ));
+	add( new SplitDirection(        "split rules with direction 'both'"  ));
+        add( new addLoopbackForRedirect(
+                 "add loopback to rules that permit redirected services" ) );
+	add( new ExpandMultipleAddresses(
+                 "expand objects with multiple addresses" ) );
+        add( new checkForDynamicInterfacesOfOtherObjects(
+                 "check for dynamic interfaces of other hosts and firewalls" ));
+        add( new MACFiltering(          "verify for MAC address filtering"   ));
+        add( new checkForUnnumbered(    "check for unnumbered interfaces"    ));
+	add( new addressRanges(         "expand address range objects"       ));
+	add( new splitServices(       "split rules with different protocols"));
+	add( new separateTCPWithFlags("separate TCP services with flags"    ));
         add( new separateSrcPort("split on TCP and UDP with source ports"));
-	add( new verifyCustomServices(  "verify custom services for this platform") );
-//	add( new ProcessScrubOption(    "process 'scrub' option"         ) );
-	add( new SpecialServices(       "check for special services"     ) );
-	add( new setQuickFlag(          "set 'quick' flag"               ) );
-        add( new checkForZeroAddr(      "check for zero addresses"       ) );
-        add( new convertInterfaceIdToStr("prepare interface assignments" ) );
+	add( new verifyCustomServices(
+                 "verify custom services for this platform"));
+//	add( new ProcessScrubOption(    "process 'scrub' option"         ));
+	add( new SpecialServices(       "check for special services"     ));
+	add( new setQuickFlag(          "set 'quick' flag"               ));
+        add( new checkForZeroAddr(      "check for zero addresses"       ));
+        add( new convertInterfaceIdToStr("prepare interface assignments" ));
 
-        add( new createTables(      "create tables"    ) );
-//        add( new PrintTables(       "print tables"     ) );
+        add( new createTables(      "create tables"    ));
+//        add( new PrintTables(       "print tables"     ));
 
-        add( new PrintRule(             "generate pf code" ) );
+        add( new PrintRule(             "generate pf code" ));
         add( new simplePrintProgress() );
 
         runRuleProcessors();
