@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp,v 1.22 2007/03/14 05:22:58 vkurland Exp $
+  $Id: PolicyCompiler_pf_writers.cpp,v 1.25 2007/07/14 21:08:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -25,6 +25,7 @@
 
 #include "PolicyCompiler_pf.h"
 
+#include "fwbuilder/Firewall.h"
 #include "fwbuilder/AddressRange.h"
 #include "fwbuilder/RuleElement.h"
 #include "fwbuilder/IPService.h"
@@ -188,7 +189,8 @@ void PolicyCompiler_pf::PrintRule::_printDirection(PolicyRule *rule)
 
 void PolicyCompiler_pf::PrintRule::_printLogging(PolicyRule *rule)
 {
-    if (rule->getLogging()) compiler->output << " log ";
+    if (rule->getAction() != PolicyRule::Branch && 
+        rule->getLogging()) compiler->output << " log ";
 }
 
 void PolicyCompiler_pf::PrintRule::_printLabel(PolicyRule *rule)
@@ -620,6 +622,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
     FWOptions  *ruleopt =rule->getOptionsObject();
+    string version=compiler->fw->getStr("version");
 
 //    cerr << endl;
 //    cerr << "Rule " << rule->getPosition() << endl;
@@ -683,7 +686,6 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 
     _printTag(rule);
 
-//    cerr << "CP 3" << endl;
 /* 
  * Dealing with "keep state" and "modulate state" flags
  *
@@ -692,23 +694,68 @@ bool PolicyCompiler_pf::PrintRule::processNext()
  *    all services in a rule are of the same protocol, therefore we can simply
  *    check type of srv
  */
-    if ( ! ruleopt->getBool("stateless") && 
-         (rule->getAction()==PolicyRule::Accept ||
-          rule->getAction()==PolicyRule::Tag ||
-          rule->getAction()==PolicyRule::Route)
-    )
+    if ( ! ruleopt->getBool("stateless") )
     {
 
         TCPService *tcpsrv=TCPService::cast(srv);
 
-        if ( ! compiler->getCachedFwOpt()->getBool("accept_new_tcp_with_no_syn") &&
-             tcpsrv!=NULL && !tcpsrv->inspectFlags() )
-            compiler->output << "flags S/SA ";
+        if (tcpsrv!=NULL && ! tcpsrv->inspectFlags() )
+        {
+            // tcp service, no special flag match
 
-	if (compiler->getCachedFwOpt()->getBool("modulate_state") && tcpsrv!=NULL)
+            if ( version == "4.x")
+            {
+                if (compiler->getCachedFwOpt()->getBool(
+                        "accept_new_tcp_with_no_syn") )
+                    // v4.x, accept connections opened prior to restart
+                    compiler->output << "flags any ";
+                // else - no 'flags' option since in 4.x
+                // 'flags S/SA' is the default
+                if (ruleopt->getBool("pf_keep_state") )
+                    compiler->output << "keep state ";
+            } else
+            {
+                // v3.x
+                if ( compiler->getCachedFwOpt()->getBool(
+                         "accept_new_tcp_with_no_syn") )
+                {
+                    // no 'flags ' option needed
+                    ;
+                } else
+                    // v3.x, stateful
+                    compiler->output << "flags S/SA ";
+            }
+        }
+
+	if (compiler->getCachedFwOpt()->getBool("modulate_state") &&
+            tcpsrv!=NULL)
 	    compiler->output << "modulate state ";
 	else
-	    compiler->output << "keep state ";
+        {
+            /*
+             * "flags S/SA keep state" is implicit in 4.x
+             * However see section "1.2. Operational changes" in
+             *  http://www.openbsd.org/faq/upgrade41.html
+             *
+             * Quote:
+             *
+             * In particular care should be taken with the enc0
+             * interface, as floating states are a potential problem
+             * for filtering IPsec traffic: states need to be
+             * interface bound, to avoid permitting unencrypted
+             * traffic should isakmpd(8) exit. Therefore all rules on
+             * the enc0 interface should explicitly set keep state
+             * (if-bound).
+             *
+             * This seems to imply that even though "keep state" is
+             * the default, it should be explicitly used with enc0
+             * interface. Adding rule option "Set 'keep state'
+             * explicitly" to cope with this.
+             */
+            if ( version != "4.x" ||
+                 compiler->getCachedFwOpt()->getBool("pf_keep_state"))
+                compiler->output << "keep state ";
+        }
 
         int nopt=0;
         if (ruleopt->getInt("pf_rule_max_state")>0)        nopt++;
@@ -725,7 +772,8 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 
             if (ruleopt->getInt("pf_rule_max_state")>0)
             {
-                compiler->output << " max " << ruleopt->getInt("pf_rule_max_state");
+                compiler->output << " max "
+                                 << ruleopt->getInt("pf_rule_max_state");
                 not_the_first = true;
             }
 
@@ -780,6 +828,12 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 
             if (nopt>1) compiler->output << " ) ";
         }
+    } else
+    {
+        // stateless rule
+        if ( version == "4.x")
+            // v4.x, stateless rule
+            compiler->output << "no state ";
     }
 
     if (rule->getBool("allow_opts")) compiler->output << "allow-opts  ";
